@@ -23,7 +23,7 @@
  */
 package htsjdk.samtools;
 
-import javax.xml.bind.annotation.XmlTransient;
+
 import java.io.Serializable;
 import java.util.LinkedHashMap;
 import java.util.Map;
@@ -33,7 +33,7 @@ import java.util.Set;
  * Base class for the various concrete records in a SAM header, providing uniform
  * access to the attributes.
  */
-@XmlTransient /* don't consider this class for XML-serialization */
+
 public abstract class AbstractSAMHeaderRecord implements Serializable {
     public static final long serialVersionUID = 1L;
 
