@@ -24,6 +24,7 @@
 package htsjdk.samtools;
 
 import htsjdk.samtools.util.BinaryCodec;
+import htsjdk.samtools.util.Log;
 import htsjdk.samtools.util.RuntimeEOFException;
 import htsjdk.samtools.util.SortingCollection;
 
@@ -31,15 +32,21 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.util.Arrays;
 
+import static htsjdk.samtools.SAMTag.CG;
+
 /**
  * Class for translating between in-memory and disk representation of BAMRecord.
  */
 public class BAMRecordCodec implements SortingCollection.Codec<SAMRecord> {
+    private final static Log LOG = Log.getInstance(BAMRecordCodec.class);
+
     private final SAMFileHeader header;
     private final BinaryCodec binaryCodec = new BinaryCodec();
     private final BinaryTagCodec binaryTagCodec = new BinaryTagCodec(binaryCodec);
     private final SAMRecordFactory samRecordFactory;
 
+    private boolean isReferenceSizeWarningShowed = false;
+
     public BAMRecordCodec(final SAMFileHeader header) {
         this(header, new DefaultSAMRecordFactory());
     }
@@ -55,26 +62,33 @@ public class BAMRecordCodec implements SortingCollection.Codec<SAMRecord> {
         return new BAMRecordCodec(this.header, this.samRecordFactory);
     }
 
-
-    /** Sets the output stream that records will be written to. */
+    /**
+     * Sets the output stream that records will be written to.
+     */
     @Override
     public void setOutputStream(final OutputStream os) {
         this.binaryCodec.setOutputStream(os);
     }
 
-    /** Sets the output stream that records will be written to. */
+    /**
+     * Sets the output stream that records will be written to.
+     */
     public void setOutputStream(final OutputStream os, final String filename) {
         this.binaryCodec.setOutputStream(os);
         this.binaryCodec.setOutputFileName(filename);
     }
 
-    /** Sets the input stream that records will be read from. */
+    /**
+     * Sets the input stream that records will be read from.
+     */
     @Override
     public void setInputStream(final InputStream is) {
         this.binaryCodec.setInputStream(is);
     }
 
-    /** Sets the input stream that records will be read from. */
+    /**
+     * Sets the input stream that records will be read from.
+     */
     public void setInputStream(final InputStream is, final String filename) {
         this.binaryCodec.setInputStream(is);
         this.binaryCodec.setInputFileName(filename);
@@ -93,12 +107,21 @@ public class BAMRecordCodec implements SortingCollection.Codec<SAMRecord> {
         // Compute block size, as it is the first element of the file representation of SAMRecord
         final int readLength = alignment.getReadLength();
 
+        // if cigar is too long, put into CG tag and replace with sentinel value
+        if (alignment.getCigarLength() > BAMRecord.MAX_CIGAR_OPERATORS) {
+
+            final int[] cigarEncoding = BinaryCigarCodec.encode(alignment.getCigar());
+            alignment.setCigar(makeSentinelCigar(alignment.getCigar()));
+            alignment.setAttribute(CG.name(), cigarEncoding);
+        }
+
+        // do not combine with previous call to alignment.getCigarLength() as cigar may change in-between
         final int cigarLength = alignment.getCigarLength();
 
-        int blockSize = BAMFileConstants.FIXED_BLOCK_SIZE + alignment.getReadNameLength() + 1  + // null terminated
-                        cigarLength * 4 +
-                        (readLength + 1) / 2 + // 2 bases per byte, round up
-                        readLength;
+        int blockSize = BAMFileConstants.FIXED_BLOCK_SIZE + alignment.getReadNameLength() + 1 + // null terminated
+                cigarLength * BAMRecord.CIGAR_SIZE_MULTIPLIER +
+                (readLength + 1) / 2 + // 2 bases per byte, round up
+                readLength;
 
         final int attributesSize = alignment.getAttributesBinarySize();
         if (attributesSize != -1) {
@@ -112,13 +135,12 @@ public class BAMRecordCodec implements SortingCollection.Codec<SAMRecord> {
             }
         }
 
+        // shouldn't interact with the long-cigar above since the Sentinel Cigar has the same referenceLength as
+        // the actual cigar.
         int indexBin = 0;
-        if (alignment.getReferenceIndex() >= 0) {
-            if (alignment.getIndexingBin() != null) {
-                indexBin = alignment.getIndexingBin();
-            } else {
-                indexBin = alignment.computeIndexingBin();
-            }
+        if (alignment.getAlignmentStart() != SAMRecord.NO_ALIGNMENT_START) {
+            warnIfReferenceIsTooLargeForBinField(alignment);
+            indexBin = alignment.computeIndexingBinIfAbsent(alignment);
         }
 
         // Blurt out the elements
@@ -126,8 +148,8 @@ public class BAMRecordCodec implements SortingCollection.Codec<SAMRecord> {
         this.binaryCodec.writeInt(alignment.getReferenceIndex());
         // 0-based!!
         this.binaryCodec.writeInt(alignment.getAlignmentStart() - 1);
-        this.binaryCodec.writeUByte((short)(alignment.getReadNameLength() + 1));
-        this.binaryCodec.writeUByte((short)alignment.getMappingQuality());
+        this.binaryCodec.writeUByte((short) (alignment.getReadNameLength() + 1));
+        this.binaryCodec.writeUByte((short) alignment.getMappingQuality());
         this.binaryCodec.writeUShort(indexBin);
         this.binaryCodec.writeUShort(cigarLength);
         this.binaryCodec.writeUShort(alignment.getFlags());
@@ -142,22 +164,22 @@ public class BAMRecordCodec implements SortingCollection.Codec<SAMRecord> {
             this.binaryCodec.writeBytes(variableLengthBinaryBlock);
         } else {
             if (alignment.getReadLength() != alignment.getBaseQualities().length &&
-                alignment.getBaseQualities().length != 0) {
+                    alignment.getBaseQualities().length != 0) {
                 throw new RuntimeException("Mismatch between read length and quals length writing read " +
-                alignment.getReadName() + "; read length: " + alignment.getReadLength() +
-                "; quals length: " + alignment.getBaseQualities().length);
+                        alignment.getReadName() + "; read length: " + alignment.getReadLength() +
+                        "; quals length: " + alignment.getBaseQualities().length);
             }
             this.binaryCodec.writeString(alignment.getReadName(), false, true);
             final int[] binaryCigar = BinaryCigarCodec.encode(alignment.getCigar());
             for (final int cigarElement : binaryCigar) {
                 // Assumption that this will fit into an integer, despite the fact
-                // that it is specced as a uint.
+                // that it is spec'ed as a uint.
                 this.binaryCodec.writeInt(cigarElement);
             }
             try {
                 this.binaryCodec.writeBytes(SAMUtils.bytesToCompressedBases(alignment.getReadBases()));
-            } catch ( final IllegalArgumentException ex ) {
-                final String msg = ex.getMessage() + " in read: " +  alignment.getReadName();
+            } catch (final IllegalArgumentException ex) {
+                final String msg = ex.getMessage() + " in read: " + alignment.getReadName();
                 throw new IllegalStateException(msg, ex);
             }
             byte[] qualities = alignment.getBaseQualities();
@@ -174,26 +196,63 @@ public class BAMRecordCodec implements SortingCollection.Codec<SAMRecord> {
         }
     }
 
+    /**
+     * Create a "Sentinel" cigar that will be placed in BAM file when the actual cigar has more than 0xffff operator,
+     * which are not supported by the bam format. The actual cigar will be encoded and placed in the CG attribute.
+     * @param cigar actual cigar to create sentinel cigar for
+     * @return sentinel cigar xSyN with readLength (x) and referenceLength (y) matching the input cigar.
+     */
+    public static Cigar makeSentinelCigar(final Cigar cigar) {
+        // in BAM there are only 28 bits for a cigar operator, so this a protection against overflow.
+        if (cigar.getReadLength() > BAMRecord.MAX_CIGAR_ELEMENT_LENGTH) {
+            throw new IllegalArgumentException(
+                    String.format(
+                            "Cannot encode (to BAM) a record with more than %d cigar operations and a read-length greater than %d.",
+                            BAMRecord.MAX_CIGAR_OPERATORS, BAMRecord.MAX_CIGAR_ELEMENT_LENGTH));
+        }
+
+        if (cigar.getReferenceLength() > BAMRecord.MAX_CIGAR_ELEMENT_LENGTH) {
+            throw new IllegalArgumentException(
+                    String.format(
+                            "Cannot encode (to BAM) a record that has than %d cigar operations and spans more than %d bases on the reference.",
+                            BAMRecord.MAX_CIGAR_OPERATORS, BAMRecord.MAX_CIGAR_ELEMENT_LENGTH));
+        }
+
+        return new Cigar(Arrays.asList(
+                new CigarElement(cigar.getReadLength(), CigarOperator.S),
+                new CigarElement(cigar.getReferenceLength(), CigarOperator.N)));
+    }
+
+    private void warnIfReferenceIsTooLargeForBinField(final SAMRecord rec) {
+        final SAMSequenceRecord sequence = rec.getHeader() != null ? rec.getHeader().getSequence(rec.getReferenceName()) : null;
+        if (!isReferenceSizeWarningShowed
+                && sequence != null
+                && SAMUtils.isReferenceSequenceCompatibleWithBAI(sequence)
+                && rec.getValidationStringency() != ValidationStringency.SILENT) {
+            LOG.warn("Reference length is too large for BAM bin field. Values in the bin field could be incorrect.");
+            isReferenceSizeWarningShowed = true;
+        }
+    }
+
     /**
      * Read the next record from the input stream and convert into a java object.
      *
      * @return null if no more records.  Should throw exception if EOF is encountered in the middle of
-     *         a record.
+     * a record.
      */
     @Override
     public SAMRecord decode() {
-        int recordLength = 0;
+        final int recordLength;
         try {
             recordLength = this.binaryCodec.readInt();
-        }
-        catch (RuntimeEOFException e) {
+        } catch (RuntimeEOFException e) {
             return null;
         }
 
         if (recordLength < BAMFileConstants.FIXED_BLOCK_SIZE) {
             throw new SAMFormatException("Invalid record length: " + recordLength);
         }
-        
+
         final int referenceID = this.binaryCodec.readInt();
         final int coordinate = this.binaryCodec.readInt() + 1;
         final short readNameLength = this.binaryCodec.readUByte();
