@@ -17,6 +17,7 @@ import htsjdk.samtools.cram.structure.CramCompressionRecord;
 import htsjdk.samtools.cram.structure.Slice;
 import htsjdk.samtools.util.Log;
 import htsjdk.samtools.util.RuntimeIOException;
+import htsjdk.samtools.util.SequenceUtil;
 
 import java.io.IOException;
 import java.io.OutputStream;
@@ -437,7 +438,13 @@ public class CRAMContainerStreamWriter {
                     final SAMRecord restoredSamRecord = f.create(cramRecords.get(i));
                     assert (restoredSamRecord.getAlignmentStart() == samRecords.get(i).getAlignmentStart());
                     assert (restoredSamRecord.getReferenceName().equals(samRecords.get(i).getReferenceName()));
-                    assert (restoredSamRecord.getReadString().equals(samRecords.get(i).getReadString()));
+
+                    if (!restoredSamRecord.getReadString().equals(samRecords.get(i).getReadString())) {
+                        // try to fix the original read bases by normalizing them to BAM set:
+                        final byte[] originalReadBases = samRecords.get(i).getReadString().getBytes();
+                        final String originalReadBasesUpperCaseIupacNoDot = new String(SequenceUtil.toBamReadBasesInPlace(originalReadBases));
+                        assert (restoredSamRecord.getReadString().equals(originalReadBasesUpperCaseIupacNoDot));
+                    }
                     assert (restoredSamRecord.getBaseQualityString().equals(samRecords.get(i).getBaseQualityString()));
                 }
             }
