@@ -23,10 +23,12 @@
  */
 package htsjdk.samtools;
 
+import htsjdk.samtools.SAMFileHeader.SortOrder;
 import htsjdk.samtools.util.DateParser;
 import htsjdk.samtools.util.LineReader;
 import htsjdk.samtools.util.RuntimeIOException;
 import htsjdk.samtools.util.StringUtil;
+import htsjdk.samtools.util.Log;
 
 import java.io.BufferedWriter;
 import java.io.IOException;
@@ -69,6 +71,7 @@ public class SAMTextHeaderCodec {
     private static final Pattern FIELD_SEPARATOR_RE = Pattern.compile(FIELD_SEPARATOR);
 
     public static final String COMMENT_PREFIX = HEADER_LINE_START + HeaderRecordType.CO.name() + FIELD_SEPARATOR;
+    private static final Log log = Log.getInstance(SAMTextHeaderCodec.class);
 
     void setWriter(final BufferedWriter writer) {
         this.writer = writer;
@@ -231,10 +234,10 @@ public class SAMTextHeaderCodec {
 
         final String soString = parsedHeaderLine.getValue(SAMFileHeader.SORT_ORDER_TAG);
         try {
-            if (soString != null) SAMFileHeader.SortOrder.valueOf(soString);
+            if (soString != null) SortOrder.valueOf(soString);
         } catch (IllegalArgumentException e) {
             reportErrorParsingLine(HEADER_LINE_START + parsedHeaderLine.getHeaderRecordType() +
-                            " line has non-conforming SO tag value: "+ soString + ".",
+                            " line has non-conforming SO tag value: " + soString + ".",
                     SAMValidationError.Type.HEADER_TAG_NON_CONFORMING_VALUE, null);
         }
 
@@ -323,11 +326,30 @@ public class SAMTextHeaderCodec {
                             SAMValidationError.Type.HEADER_TAG_MULTIPLY_DEFINED, null);
                     continue;
                 }
+                validateSortOrderValue(keyAndValue);
                 mKeyValuePairs.put(keyAndValue[0], keyAndValue[1]);
             }
             lineValid = true;
         }
 
+        private void validateSortOrderValue(String[] value) {
+            if (SAMFileHeader.SORT_ORDER_TAG.equals(value[0])) {
+                try {
+                    SortOrder.valueOf(value[1]);
+                } catch (IllegalArgumentException e) {
+                    if (validationStringency == ValidationStringency.STRICT) {
+                        throw new SAMFormatException("Found non-conforming header SO tag: "
+                                                     + value[1]
+                                                     + ", exiting because VALIDATION_STRINGENCY=STRICT");
+                    } else if (validationStringency == ValidationStringency.LENIENT) {
+                        log.warn("Found non-conforming header SO tag: "
+                                 + value[1] + ". Treating as 'unknown'.");
+                    }
+                    value[1] = SortOrder.unknown.toString();
+                }
+            }
+        }
+
         /**
          * True if the line is recognized as one of the valid HeaderRecordTypes.
          */
@@ -462,7 +484,7 @@ public class SAMTextHeaderCodec {
     private void writeRGLine(final SAMReadGroupRecord readGroup) {
         println(getRGLine(readGroup));
     }
-    
+
     protected String getRGLine(final SAMReadGroupRecord readGroup) {
       final String[] fields = new String[2 + readGroup.getAttributes().size()];
       fields[0] = HEADER_LINE_START + HeaderRecordType.RG;
@@ -525,4 +547,4 @@ public class SAMTextHeaderCodec {
         }
         this.validationStringency = validationStringency;
     }
-}
+}
\ No newline at end of file
