@@ -226,7 +226,13 @@ public class SAMValidationError implements Serializable {
         MISMATCH_FILE_SEQ_DICT,
 
         /** Base quality is not stored for the read. */
-        QUALITY_NOT_STORED(Severity.WARNING);
+        QUALITY_NOT_STORED(Severity.WARNING),
+
+        /** A duplicate Sam tag was found in a record. */
+        DUPLICATE_SAM_TAG,
+
+        /** The CG Tag should only be used in BAM format to hold a large cigar */
+        CG_TAG_FOUND_IN_ATTRIBUTES;
 
         public final Severity severity;
 
