@@ -409,7 +409,7 @@ public class SamFileValidator {
             addError(new SAMValidationError(Type.CG_TAG_FOUND_IN_ATTRIBUTES,
                     "The CG Tag should only be used in BAM format to hold a large cigar. " +
                             "It was found containing the value: " +
-                            record.getAttribute(SAMTagUtil.getSingleton().CG), record.getReadName(), recordNumber));
+                            record.getAttribute(SAMTag.CG.getBinaryTag()), record.getReadName(), recordNumber));
         }
     }
 
