@@ -19,6 +19,7 @@ package htsjdk.samtools.cram.encoding.readfeatures;
 
 import java.io.Serializable;
 import java.util.Arrays;
+import java.util.Objects;
 
 /**
  * A read feature representing a soft clip similar to {@link htsjdk.samtools.CigarOperator#S}.
@@ -61,19 +62,24 @@ public class SoftClip implements Serializable, ReadFeature {
         this.position = position;
     }
 
-    @Override
-    public boolean equals(final Object obj) {
-        if (!(obj instanceof SoftClip))
-            return false;
-
-        final SoftClip softClip = (SoftClip) obj;
-
-        return position == softClip.position && !Arrays.equals(sequence, softClip.sequence);
-
-    }
-
     @Override
     public String toString() {
         return getClass().getSimpleName() + "[" + "position=" + position + "; bases=" + new String(sequence) + "] ";
     }
+
+    @Override
+    public boolean equals(Object o) {
+        if (this == o) return true;
+        if (o == null || getClass() != o.getClass()) return false;
+        final SoftClip softClip = (SoftClip) o;
+        return position == softClip.position &&
+                Arrays.equals(sequence, softClip.sequence);
+    }
+
+    @Override
+    public int hashCode() {
+        int result = Objects.hash(position);
+        result = 31 * result + Arrays.hashCode(sequence);
+        return result;
+    }
 }
