@@ -9,12 +9,14 @@ public class SecondaryAlignmentFilter implements SamRecordFilter {
     /**
      * Returns true if the read is marked as secondary.
      */
-    public boolean filterOut(final SAMRecord record) { return record.getNotPrimaryAlignmentFlag(); }
+    @Override
+    public boolean filterOut(final SAMRecord record) { return record.isSecondaryAlignment(); }
 
     /**
      * Returns true if either read is marked as secondary.
      */
+    @Override
     public boolean filterOut(final SAMRecord first, final SAMRecord second) {
-        return first.getNotPrimaryAlignmentFlag() || second.getNotPrimaryAlignmentFlag();
+        return first.isSecondaryAlignment() || second.isSecondaryAlignment();
     }
 }
