@@ -24,10 +24,22 @@
 
 package htsjdk.samtools.reference;
 
+import htsjdk.samtools.SAMException;
+import htsjdk.samtools.util.BlockCompressedInputStream;
+import htsjdk.samtools.util.GZIIndex;
+import htsjdk.samtools.SAMFileHeader;
+import htsjdk.samtools.SAMSequenceDictionary;
+import htsjdk.samtools.SAMTextHeaderCodec;
+import htsjdk.samtools.seekablestream.SeekableStream;
+import htsjdk.samtools.util.BufferedLineReader;
 import htsjdk.samtools.util.IOUtil;
 
+import java.io.BufferedInputStream;
 import java.io.File;
 import java.io.FileNotFoundException;
+import java.io.IOException;
+import java.io.InputStream;
+import java.nio.file.Files;
 import java.nio.file.Path;
 import java.util.HashSet;
 import java.util.Set;
@@ -81,7 +93,7 @@ public class ReferenceSequenceFileFactory {
      * @param preferIndexed if true attempt to return an indexed reader that supports non-linear traversal, else return the non-indexed reader
      */
     public static ReferenceSequenceFile getReferenceSequenceFile(final File file, final boolean truncateNamesAtWhitespace, final boolean preferIndexed) {
-        return getReferenceSequenceFile(file.toPath(), truncateNamesAtWhitespace, preferIndexed);
+        return getReferenceSequenceFile(IOUtil.toPath(file), truncateNamesAtWhitespace, preferIndexed);
     }
 
     /**
@@ -118,25 +130,83 @@ public class ReferenceSequenceFileFactory {
         // this should thrown an exception if the fasta file is not supported
         getFastaExtension(path);
         // Using faidx requires truncateNamesAtWhitespace
-        if (truncateNamesAtWhitespace && preferIndexed && IndexedFastaSequenceFile.canCreateIndexedFastaReader(path)) {
+        if (truncateNamesAtWhitespace && preferIndexed && canCreateIndexedFastaReader(path)) {
             try {
-                return new IndexedFastaSequenceFile(path);
-            }
-            catch (final FileNotFoundException e) {
-                throw new IllegalStateException("Should never happen, because existence of files has been checked.", e);
+                return IOUtil.isBlockCompressed(path, true) ? new BlockCompressedIndexedFastaSequenceFile(path) : new IndexedFastaSequenceFile(path);
+            } catch (final IOException e) {
+                throw new SAMException("Error opening FASTA: " + path, e);
             }
         } else {
             return new FastaSequenceFile(path, truncateNamesAtWhitespace);
         }
     }
 
+    /**
+     * Checks if the provided FASTA file can be open as indexed.
+     *
+     * <p>For a FASTA file to be indexed, it requires to have:
+     * <ul>
+     *     <li>Associated .fai index ({@link FastaSequenceIndex}).</li>
+     *     <li>Associated .gzi index if it is block-compressed ({@link GZIIndex}).</li>
+     * </ul>
+     *
+     * @param fastaFile the reference sequence file path.
+     * @return {@code true} if the file can be open as indexed; {@code false} otherwise.
+     */
+    public static boolean canCreateIndexedFastaReader(final Path fastaFile) {
+        // this should thrown an exception if the fasta file is not supported
+        getFastaExtension(fastaFile);
+
+        // both the FASTA file should exists and the .fai index should exist
+        if (Files.exists(fastaFile) && Files.exists(getFastaIndexFileName(fastaFile))) {
+            // open the file for checking for block-compressed input
+            try {
+                // if it is bgzip, it requires the .gzi index
+                return !IOUtil.isBlockCompressed(fastaFile, true) ||
+                        Files.exists(GZIIndex.resolveIndexNameForBgzipFile(fastaFile));
+            } catch (IOException e) {
+                return false;
+            }
+        }
+        return false;
+    }
+
+    /**
+     * Return an instance of ReferenceSequenceFile using the given fasta sequence file stream, optional index stream,
+     * and no sequence dictionary
+     *
+     * @param source The named source of the reference file (used in error messages).
+     * @param in The input stream to read the fasta file from.
+     * @param index The index, or null to return a non-indexed reader.
+     */
+    public static ReferenceSequenceFile getReferenceSequenceFile(final String source, final SeekableStream in, final FastaSequenceIndex index) {
+        return getReferenceSequenceFile(source, in, index, null, true);
+    }
+
+    /**
+     * Return an instance of ReferenceSequenceFile using the given fasta sequence file stream and optional index stream
+     * and sequence dictionary.
+     *
+     * @param source The named source of the reference file (used in error messages).
+     * @param in The input stream to read the fasta file from.
+     * @param index The index, or null to return a non-indexed reader.
+     * @param dictionary The sequence dictionary, or null if there isn't one.
+     * @param truncateNamesAtWhitespace if true, only include the first word of the sequence name
+     */
+    public static ReferenceSequenceFile getReferenceSequenceFile(final String source, final SeekableStream in, final FastaSequenceIndex index, final SAMSequenceDictionary dictionary, final boolean truncateNamesAtWhitespace) {
+        if (truncateNamesAtWhitespace && index != null) {
+            return new IndexedFastaSequenceFile(source, in, index, dictionary);
+        }
+        return new FastaSequenceFile(source, in, dictionary, truncateNamesAtWhitespace);
+    }
+
     /**
      * Returns the default dictionary name for a FASTA file.
      *
      * @param file the reference sequence file on disk.
      */
     public static File getDefaultDictionaryForReferenceSequence(final File file) {
-        return getDefaultDictionaryForReferenceSequence(file.toPath()).toFile();
+        return getDefaultDictionaryForReferenceSequence(IOUtil.toPath(file)).toFile();
     }
 
     /**
@@ -150,6 +220,22 @@ public class ReferenceSequenceFileFactory {
         return path.resolveSibling(name.substring(0, extensionIndex) + IOUtil.DICT_FILE_EXTENSION);
     }
 
+    /**
+     * Loads the sequence dictionary from a FASTA file input stream.
+     *
+     * @param in the FASTA file input stream.
+     * @return the sequence dictionary, or <code>null</code> if the header has no dictionary or it was empty.
+     */
+    public static SAMSequenceDictionary loadDictionary(final InputStream in) {
+        final SAMTextHeaderCodec codec = new SAMTextHeaderCodec();
+        final BufferedLineReader reader = new BufferedLineReader(in);
+        final SAMFileHeader header = codec.decode(reader, null);
+        if (header.getSequenceDictionary().isEmpty()) {
+            return null;
+        }
+        return header.getSequenceDictionary();
+    }
+
     /**
      * Returns the FASTA extension for the path.
      *
