@@ -29,6 +29,7 @@ import java.io.File;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.nio.file.Files;
+import java.nio.file.Path;
 import java.util.zip.CRC32;
 import java.util.zip.Deflater;
 
@@ -111,7 +112,7 @@ public class BlockCompressedOutputStream
     // so just use JDK standard.
     private final Deflater noCompressionDeflater = new Deflater(Deflater.NO_COMPRESSION, true);
     private final CRC32 crc32 = new CRC32();
-    private File file = null;
+    private Path file = null;
     private long mBlockAddress = 0;
 
 
@@ -161,8 +162,17 @@ public class BlockCompressedOutputStream
      * @param deflaterFactory custom factory to create deflaters (overrides the default)
      */
     public BlockCompressedOutputStream(final File file, final int compressionLevel, final DeflaterFactory deflaterFactory) {
-        this.file = file;
-        codec = new BinaryCodec(file, true);
+        this(IOUtil.toPath(file), compressionLevel, deflaterFactory);
+    }
+
+    /**
+     * Prepare to compress at the given compression level
+     * @param compressionLevel 1 <= compressionLevel <= 9
+     * @param deflaterFactory custom factory to create deflaters (overrides the default)
+     */
+    public BlockCompressedOutputStream(final Path path, final int compressionLevel, final DeflaterFactory deflaterFactory) {
+        this.file = path;
+        codec = new BinaryCodec(path, true);
         deflater = deflaterFactory.makeDeflater(compressionLevel, true);
         log.debug("Using deflater: " + deflater.getClass().getSimpleName());
     }
@@ -178,6 +188,17 @@ public class BlockCompressedOutputStream
         this(os, file, defaultCompressionLevel);
     }
 
+    /**
+     * Uses default compression level, which is 5 unless changed by setCompressionLevel
+     * Note: this constructor uses the default {@link DeflaterFactory}, see {@link #getDefaultDeflaterFactory()}.
+     * Use {@link #BlockCompressedOutputStream(OutputStream, File, int, DeflaterFactory)} to specify a custom factory.
+     *
+     * @param file may be null
+     */
+    public BlockCompressedOutputStream(final OutputStream os, final Path file) {
+        this(os, file, defaultCompressionLevel);
+    }
+
     /**
      * Note: this constructor uses the default {@link DeflaterFactory}, see {@link #getDefaultDeflaterFactory()}.
      * Use {@link #BlockCompressedOutputStream(OutputStream, File, int, DeflaterFactory)} to specify a custom factory.
@@ -186,6 +207,14 @@ public class BlockCompressedOutputStream
         this(os, file, compressionLevel, defaultDeflaterFactory);
     }
 
+    /**
+     * Note: this constructor uses the default {@link DeflaterFactory}, see {@link #getDefaultDeflaterFactory()}.
+     * Use {@link #BlockCompressedOutputStream(OutputStream, File, int, DeflaterFactory)} to specify a custom factory.
+     */
+    public BlockCompressedOutputStream(final OutputStream os, final Path file, final int compressionLevel) {
+        this(os, file, compressionLevel, defaultDeflaterFactory);
+    }
+
     /**
      * Creates the output stream.
      * @param os output stream to create a BlockCompressedOutputStream from
@@ -194,10 +223,21 @@ public class BlockCompressedOutputStream
      * @param deflaterFactory custom factory to create deflaters (overrides the default)
      */
     public BlockCompressedOutputStream(final OutputStream os, final File file, final int compressionLevel, final DeflaterFactory deflaterFactory) {
+        this(os, IOUtil.toPath(file), compressionLevel, deflaterFactory);
+    }
+
+    /**
+     * Creates the output stream.
+     * @param os output stream to create a BlockCompressedOutputStream from
+     * @param file file to which to write the output or null if not available
+     * @param compressionLevel the compression level (0-9)
+     * @param deflaterFactory custom factory to create deflaters (overrides the default)
+     */
+    public BlockCompressedOutputStream(final OutputStream os, final Path file, final int compressionLevel, final DeflaterFactory deflaterFactory) {
         this.file = file;
         codec = new BinaryCodec(os);
         if (file != null) {
-            codec.setOutputFileName(file.getAbsolutePath());
+            codec.setOutputFileName(file.toAbsolutePath().toUri().toString());
         }
         deflater = deflaterFactory.makeDeflater(compressionLevel, true);
         log.debug("Using deflater: " + deflater.getClass().getSimpleName());
@@ -283,7 +323,7 @@ public class BlockCompressedOutputStream
         codec.writeBytes(BlockCompressedStreamConstants.EMPTY_GZIP_BLOCK);
         codec.close();
         // Can't re-open something that is not a regular file, e.g. a named pipe or an output stream
-        if (this.file == null || !this.file.isFile() || !Files.isRegularFile(this.file.toPath())) return;
+        if (this.file == null || !Files.isRegularFile(this.file)) return;
         if (BlockCompressedInputStream.checkTermination(this.file) !=
                 BlockCompressedInputStream.FileTermination.HAS_TERMINATOR_BLOCK) {
             throw new IOException("Terminator block not found after closing BGZF file " + this.file);
