@@ -26,7 +26,6 @@ package htsjdk.samtools.util;
 import htsjdk.samtools.Defaults;
 
 import java.io.File;
-import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
@@ -50,14 +49,15 @@ import java.util.TreeSet;
  * to a temporary directory if there are more records added than will fit in memory.  As a result of this,
  * the objects returned may not be identical to the objects added to the collection, but they should be
  * equal as determined by the codec used to write them to disk and read them back.
- *
+ * <p>
  * When iterating over the collection, the number of file handles required is numRecordsInCollection/maxRecordsInRam.
  * If this becomes a limiting factor, a file handle cache could be added.
- *
+ * <p>
  * If Snappy DLL is available and snappy.disable system property is not set to true, then Snappy is used
  * to compress temporary files.
  */
 public class SortingCollection<T> implements Iterable<T> {
+    private static final Log log = Log.getInstance(SortingCollection.class);
 
     /**
      * Client must implement this class, which defines the way in which records are written to and
@@ -66,23 +66,24 @@ public class SortingCollection<T> implements Iterable<T> {
     public interface Codec<T> extends Cloneable {
         /**
          * Where to write encoded output
-         * @param os
          */
         void setOutputStream(OutputStream os);
 
         /**
          * Where to read encoded input from
-         * @param is
          */
         void setInputStream(InputStream is);
+
         /**
          * Write object to output stream
+         *
          * @param val what to write
          */
         void encode(T val);
 
         /**
          * Read the next record from the input stream and convert into a java object.
+         *
          * @return null if no more records.  Should throw exception if EOF is encountered in the middle of
          * a record.
          */
@@ -96,12 +97,11 @@ public class SortingCollection<T> implements Iterable<T> {
         Codec<T> clone();
     }
 
-    /** Directories where files of sorted records go. */
+    /**
+     * Directories where files of sorted records go.
+     */
     private final Path[] tmpDirs;
 
-    /** The minimum amount of space free on a temp filesystem to write a file there. */
-    private final long TMP_SPACE_FREE = IOUtil.FIVE_GBS;
-
     /**
      * Used to write records to file, and used as a prototype to create codecs for reading.
      */
@@ -129,18 +129,23 @@ public class SortingCollection<T> implements Iterable<T> {
 
     private boolean destructiveIteration = true;
 
-    private TempStreamFactory tempStreamFactory = new TempStreamFactory();
+    private final TempStreamFactory tempStreamFactory = new TempStreamFactory();
+
+    private final boolean printRecordSizeSampling;
 
     /**
      * Prepare to accumulate records to be sorted
-     * @param componentType Class of the record to be sorted.  Necessary because of Java generic lameness.
-     * @param codec For writing records to file and reading them back into RAM
-     * @param comparator Defines output sort order
+     *
+     * @param componentType   Class of the record to be sorted.  Necessary because of Java generic lameness.
+     * @param codec           For writing records to file and reading them back into RAM
+     * @param comparator      Defines output sort order
      * @param maxRecordsInRam how many records to accumulate before spilling to disk
-     * @param tmpDir Where to write files of records that will not fit in RAM
+     * @param printRecordSizeSampling If true record size will be sampled and output at DEBUG log level
+     * @param tmpDir          Where to write files of records that will not fit in RAM
      */
     private SortingCollection(final Class<T> componentType, final SortingCollection.Codec<T> codec,
-                             final Comparator<T> comparator, final int maxRecordsInRam, final Path... tmpDir) {
+                              final Comparator<T> comparator, final int maxRecordsInRam,
+                              final boolean printRecordSizeSampling, final Path... tmpDir) {
         if (maxRecordsInRam <= 0) {
             throw new IllegalArgumentException("maxRecordsInRam must be > 0");
         }
@@ -153,7 +158,10 @@ public class SortingCollection<T> implements Iterable<T> {
         this.codec = codec;
         this.comparator = comparator;
         this.maxRecordsInRam = maxRecordsInRam;
-        this.ramRecords = (T[])Array.newInstance(componentType, maxRecordsInRam);
+        @SuppressWarnings("unchecked")
+        T[] ramRecords = (T[]) Array.newInstance(componentType, maxRecordsInRam);
+        this.ramRecords = ramRecords;
+        this.printRecordSizeSampling = printRecordSizeSampling;
     }
 
     public void add(final T rec) {
@@ -164,7 +172,27 @@ public class SortingCollection<T> implements Iterable<T> {
             throw new IllegalStateException("Cannot add after calling iterator()");
         }
         if (numRecordsInRam == maxRecordsInRam) {
+
+            long startMem = 0;
+            if (printRecordSizeSampling) {
+                // Garbage collect and get free memory
+                Runtime.getRuntime().gc();
+                startMem = Runtime.getRuntime().freeMemory();
+            }
+
             spillToDisk();
+
+            if (printRecordSizeSampling) {
+                //Garbage collect again and get free memory
+                Runtime.getRuntime().gc();
+                long endMem = Runtime.getRuntime().freeMemory();
+
+                long usedBytes = endMem - startMem;
+                log.debug(String.format("%d records in ram required approximately %s memory or %s per record. ", maxRecordsInRam,
+                        StringUtil.humanReadableByteCount(usedBytes),
+                        StringUtil.humanReadableByteCount(usedBytes / maxRecordsInRam)));
+
+            }
         }
         ramRecords[numRecordsInRam++] = rec;
     }
@@ -217,43 +245,38 @@ public class SortingCollection<T> implements Iterable<T> {
      */
     public void spillToDisk() {
         try {
-            Arrays.sort(this.ramRecords, 0, this.numRecordsInRam, this.comparator);
+            Arrays.parallelSort(this.ramRecords, 0, this.numRecordsInRam, this.comparator);
+
             final Path f = newTempFile();
-            OutputStream os = null;
-            try {
-                os = tempStreamFactory.wrapTempOutputStream(Files.newOutputStream(f), Defaults.BUFFER_SIZE);
+            try (OutputStream os
+                         = tempStreamFactory.wrapTempOutputStream(Files.newOutputStream(f), Defaults.BUFFER_SIZE)) {
                 this.codec.setOutputStream(os);
                 for (int i = 0; i < this.numRecordsInRam; ++i) {
                     this.codec.encode(ramRecords[i]);
                     // Facilitate GC
                     this.ramRecords[i] = null;
                 }
-
                 os.flush();
             } catch (RuntimeIOException ex) {
                 throw new RuntimeIOException("Problem writing temporary file " + f.toUri() +
                         ".  Try setting TMP_DIR to a file system with lots of space.", ex);
-            } finally {
-                if (os != null) {
-                    os.close();
-                }
             }
 
             this.numRecordsInRam = 0;
             this.files.add(f);
-
-        }
-        catch (IOException e) {
+        } catch (IOException e) {
             throw new RuntimeIOException(e);
         }
     }
 
+
     /**
      * Creates a new tmp file on one of the available temp filesystems, registers it for deletion
      * on JVM exit and then returns it.
      */
     private Path newTempFile() throws IOException {
-        return IOUtil.newTempPath("sortingcollection.", ".tmp", this.tmpDirs, TMP_SPACE_FREE);
+        /* The minimum amount of space free on a temp filesystem to write a file there. */
+        return IOUtil.newTempPath("sortingcollection.", ".tmp", this.tmpDirs, IOUtil.FIVE_GBS);
     }
 
     /**
@@ -288,12 +311,11 @@ public class SortingCollection<T> implements Iterable<T> {
     /**
      * Syntactic sugar around the ctor, to save some typing of type parameters
      *
-     * @param componentType Class of the record to be sorted.  Necessary because of Java generic lameness.
-     * @param codec For writing records to file and reading them back into RAM
-     * @param comparator Defines output sort order
+     * @param componentType   Class of the record to be sorted.  Necessary because of Java generic lameness.
+     * @param codec           For writing records to file and reading them back into RAM
+     * @param comparator      Defines output sort order
      * @param maxRecordsInRAM how many records to accumulate in memory before spilling to disk
-     * @param tmpDir Where to write files of records that will not fit in RAM
-     *
+     * @param tmpDir          Where to write files of records that will not fit in RAM
      * @deprecated since 2017-09. Use {@link #newInstance(Class, Codec, Comparator, int, Path...)} instead
      */
     @Deprecated
@@ -302,19 +324,18 @@ public class SortingCollection<T> implements Iterable<T> {
                                                        final Comparator<T> comparator,
                                                        final int maxRecordsInRAM,
                                                        final File... tmpDir) {
-        return new SortingCollection<T>(componentType, codec, comparator, maxRecordsInRAM, Arrays.stream(tmpDir).map(File::toPath).toArray(Path[]::new));
+        return new SortingCollection<>(componentType, codec, comparator, maxRecordsInRAM, false, Arrays.stream(tmpDir).map(File::toPath).toArray(Path[]::new));
 
     }
 
     /**
      * Syntactic sugar around the ctor, to save some typing of type parameters
      *
-     * @param componentType Class of the record to be sorted.  Necessary because of Java generic lameness.
-     * @param codec For writing records to file and reading them back into RAM
-     * @param comparator Defines output sort order
+     * @param componentType   Class of the record to be sorted.  Necessary because of Java generic lameness.
+     * @param codec           For writing records to file and reading them back into RAM
+     * @param comparator      Defines output sort order
      * @param maxRecordsInRAM how many records to accumulate in memory before spilling to disk
-     * @param tmpDirs Where to write files of records that will not fit in RAM
-     *
+     * @param tmpDirs         Where to write files of records that will not fit in RAM
      * @deprecated since 2017-09. Use {@link #newInstanceFromPaths(Class, Codec, Comparator, int, Collection)} instead
      */
     @Deprecated
@@ -323,70 +344,105 @@ public class SortingCollection<T> implements Iterable<T> {
                                                        final Comparator<T> comparator,
                                                        final int maxRecordsInRAM,
                                                        final Collection<File> tmpDirs) {
-        return new SortingCollection<T>(componentType,
-                                        codec,
-                                        comparator,
-                                        maxRecordsInRAM,
-                                        tmpDirs.stream().map(File::toPath).toArray(Path[]::new));
+        return new SortingCollection<>(componentType,
+                codec,
+                comparator,
+                maxRecordsInRAM,
+                false,
+                tmpDirs.stream().map(File::toPath).toArray(Path[]::new));
 
     }
 
-
     /**
      * Syntactic sugar around the ctor, to save some typing of type parameters.  Writes files to java.io.tmpdir
      *
-     * @param componentType Class of the record to be sorted.  Necessary because of Java generic lameness.
-     * @param codec For writing records to file and reading them back into RAM
-     * @param comparator Defines output sort order
+     * @param componentType    Class of the record to be sorted.  Necessary because of Java generic lameness.
+     * @param codec            For writing records to file and reading them back into RAM
+     * @param comparator       Defines output sort order
+     * @param maxRecordsInRAM  how many records to accumulate in memory before spilling to disk
+     * @param printRecordSizeSampling If true record size will be sampled and output at DEBUG log level
+     */
+    public static <T> SortingCollection<T> newInstance(final Class<T> componentType,
+                                                       final SortingCollection.Codec<T> codec,
+                                                       final Comparator<T> comparator,
+                                                       final int maxRecordsInRAM,
+                                                       final boolean printRecordSizeSampling) {
+        final Path tmpDir = Paths.get(System.getProperty("java.io.tmpdir"));
+        return new SortingCollection<>(componentType, codec, comparator, maxRecordsInRAM, printRecordSizeSampling, tmpDir);
+    }
+
+    /**
+     * Syntactic sugar around the ctor, to save some typing of type parameters
+     *
+     * @param componentType    Class of the record to be sorted.  Necessary because of Java generic lameness.
+     * @param codec            For writing records to file and reading them back into RAM
+     * @param comparator       Defines output sort order
+     * @param maxRecordsInRAM  how many records to accumulate in memory before spilling to disk
+     * @param printRecordSizeSampling If true record size will be sampled and output at DEBUG log level
+     * @param tmpDir           Where to write files of records that will not fit in RAM
+     */
+    public static <T> SortingCollection<T> newInstance(final Class<T> componentType,
+                                                       final SortingCollection.Codec<T> codec,
+                                                       final Comparator<T> comparator,
+                                                       final int maxRecordsInRAM,
+                                                       final boolean printRecordSizeSampling,
+                                                       final Path... tmpDir) {
+        return new SortingCollection<>(componentType, codec, comparator, maxRecordsInRAM, printRecordSizeSampling, tmpDir);
+    }
+
+    /**
+     * Syntactic sugar around the ctor, to save some typing of type parameters.  Writes files to java.io.tmpdir
+     *
+     * @param componentType   Class of the record to be sorted.  Necessary because of Java generic lameness.
+     * @param codec           For writing records to file and reading them back into RAM
+     * @param comparator      Defines output sort order
      * @param maxRecordsInRAM how many records to accumulate in memory before spilling to disk
      */
     public static <T> SortingCollection<T> newInstance(final Class<T> componentType,
                                                        final SortingCollection.Codec<T> codec,
                                                        final Comparator<T> comparator,
                                                        final int maxRecordsInRAM) {
-
         final Path tmpDir = Paths.get(System.getProperty("java.io.tmpdir"));
-        return new SortingCollection<T>(componentType, codec, comparator, maxRecordsInRAM, tmpDir);
+        return new SortingCollection<>(componentType, codec, comparator, maxRecordsInRAM, false, tmpDir);
     }
 
     /**
      * Syntactic sugar around the ctor, to save some typing of type parameters
      *
-     * @param componentType Class of the record to be sorted.  Necessary because of Java generic lameness.
-     * @param codec For writing records to file and reading them back into RAM
-     * @param comparator Defines output sort order
+     * @param componentType   Class of the record to be sorted.  Necessary because of Java generic lameness.
+     * @param codec           For writing records to file and reading them back into RAM
+     * @param comparator      Defines output sort order
      * @param maxRecordsInRAM how many records to accumulate in memory before spilling to disk
-     * @param tmpDir Where to write files of records that will not fit in RAM
+     * @param tmpDir          Where to write files of records that will not fit in RAM
      */
     public static <T> SortingCollection<T> newInstance(final Class<T> componentType,
-            final SortingCollection.Codec<T> codec,
-            final Comparator<T> comparator,
-            final int maxRecordsInRAM,
-            final Path... tmpDir) {
-        return new SortingCollection<T>(componentType, codec, comparator, maxRecordsInRAM, tmpDir);
-
+                                                       final SortingCollection.Codec<T> codec,
+                                                       final Comparator<T> comparator,
+                                                       final int maxRecordsInRAM,
+                                                       final Path... tmpDir) {
+        return new SortingCollection<>(componentType, codec, comparator, maxRecordsInRAM, false, tmpDir);
     }
 
     /**
      * Syntactic sugar around the ctor, to save some typing of type parameters
      *
-     * @param componentType Class of the record to be sorted.  Necessary because of Java generic lameness.
-     * @param codec For writing records to file and reading them back into RAM
-     * @param comparator Defines output sort order
+     * @param componentType   Class of the record to be sorted.  Necessary because of Java generic lameness.
+     * @param codec           For writing records to file and reading them back into RAM
+     * @param comparator      Defines output sort order
      * @param maxRecordsInRAM how many records to accumulate in memory before spilling to disk
-     * @param tmpDirs Where to write files of records that will not fit in RAM
+     * @param tmpDirs         Where to write files of records that will not fit in RAM
      */
     public static <T> SortingCollection<T> newInstanceFromPaths(final Class<T> componentType,
-            final SortingCollection.Codec<T> codec,
-            final Comparator<T> comparator,
-            final int maxRecordsInRAM,
-            final Collection<Path> tmpDirs) {
-        return new SortingCollection<T>(componentType,
+                                                                final SortingCollection.Codec<T> codec,
+                                                                final Comparator<T> comparator,
+                                                                final int maxRecordsInRAM,
+                                                                final Collection<Path> tmpDirs) {
+        return new SortingCollection<>(componentType,
                 codec,
                 comparator,
                 maxRecordsInRAM,
+                false,
                 tmpDirs.toArray(new Path[tmpDirs.size()]));
-
     }
 
     /**
@@ -396,10 +452,10 @@ public class SortingCollection<T> implements Iterable<T> {
         private int iterationIndex = 0;
 
         InMemoryIterator() {
-            Arrays.sort(SortingCollection.this.ramRecords,
-                        0,
-                        SortingCollection.this.numRecordsInRam,
-                        SortingCollection.this.comparator);
+            Arrays.parallelSort(SortingCollection.this.ramRecords,
+                    0,
+                    SortingCollection.this.numRecordsInRam,
+                    SortingCollection.this.comparator);
         }
 
         @Override
@@ -434,7 +490,7 @@ public class SortingCollection<T> implements Iterable<T> {
      * Each file is has records in sort order within the file.
      * This iterator automatically closes when it iterates to the end, but if not iterating
      * to the end it is a good idea to call close().
-     *
+     * <p>
      * Algorithm: MergingIterator maintains a PriorityQueue of PeekFileRecordIterators.
      * Each PeekFileRecordIterator iterates through a file in which the records are sorted.
      * The comparator for PeekFileRecordIterator used by the PriorityQueue peeks at the next record from
@@ -448,19 +504,47 @@ public class SortingCollection<T> implements Iterable<T> {
         private final TreeSet<PeekFileRecordIterator> queue;
 
         MergingIterator() {
-            this.queue = new TreeSet<PeekFileRecordIterator>(new PeekFileRecordIteratorComparator());
+            this.queue = new TreeSet<>(new PeekFileRecordIteratorComparator());
             int n = 0;
-            for (final Path f : SortingCollection.this.files) {
-                final FileRecordIterator it = new FileRecordIterator(f);
+            log.info(String.format("Creating merging iterator from %d files", files.size()));
+            int suggestedBufferSize = checkMemoryAndAdjustBuffer(files.size());
+            for (final Path f : files) {
+                final FileRecordIterator it = new FileRecordIterator(f, suggestedBufferSize);
                 if (it.hasNext()) {
                     this.queue.add(new PeekFileRecordIterator(it, n++));
-                }
-                else {
+                } else {
                     it.close();
                 }
             }
         }
 
+        // Since we need to open and buffer all temp files in the sorting collection at once it is important
+        // to have enough memory left to do this. This method checks to make sure that, given the number of files and
+        // the size of the buffer, we can reasonably open all files. If we can't it will return a buffer size that
+        // is appropriate given the number of temp files and the amount of memory left on the heap. If there isn't
+        // enough memory for buffering it will return zero and all reading will be unbuffered.
+        private int checkMemoryAndAdjustBuffer(int numFiles) {
+            int bufferSize = Defaults.BUFFER_SIZE;
+            // garbage collect so that our calculation is accurate.
+            Runtime.getRuntime().gc();
+
+            // There is ~20k in overhead per file.
+            final long freeMemory = Runtime.getRuntime().freeMemory() - (numFiles * 20 * 1024);
+            // use the floor value from the divide
+            final int memoryPerFile = (int) (freeMemory / numFiles);
+
+            if (memoryPerFile < 0) {
+                log.warn("There is not enough memory per file for buffering. Reading will be unbuffered.");
+                bufferSize = 0;
+            } else if (bufferSize > memoryPerFile) {
+                log.warn(String.format("Default io buffer size of %s is larger than available memory per file of %s.",
+                        StringUtil.humanReadableByteCount(bufferSize),
+                        StringUtil.humanReadableByteCount(memoryPerFile)));
+                bufferSize = memoryPerFile;
+            }
+            return bufferSize;
+        }
+
         @Override
         public boolean hasNext() {
             return !this.queue.isEmpty();
@@ -476,9 +560,8 @@ public class SortingCollection<T> implements Iterable<T> {
             final T ret = fileIterator.next();
             if (fileIterator.hasNext()) {
                 this.queue.add(fileIterator);
-            }
-            else {
-                ((CloseableIterator<T>)fileIterator.getUnderlyingIterator()).close();
+            } else {
+                ((CloseableIterator<T>) fileIterator.getUnderlyingIterator()).close();
             }
 
             return ret;
@@ -493,7 +576,7 @@ public class SortingCollection<T> implements Iterable<T> {
         public void close() {
             while (!this.queue.isEmpty()) {
                 final PeekFileRecordIterator it = this.queue.pollFirst();
-                ((CloseableIterator<T>)it.getUnderlyingIterator()).close();
+                ((CloseableIterator<T>) it.getUnderlyingIterator()).close();
             }
         }
     }
@@ -507,15 +590,14 @@ public class SortingCollection<T> implements Iterable<T> {
         private final Codec<T> codec;
         private T currentRecord = null;
 
-        FileRecordIterator(final Path file) {
+        FileRecordIterator(final Path file, final int bufferSize) {
             this.file = file;
             try {
                 this.is = Files.newInputStream(file);
                 this.codec = SortingCollection.this.codec.clone();
-                this.codec.setInputStream(tempStreamFactory.wrapTempInputStream(this.is, Defaults.BUFFER_SIZE));
+                this.codec.setInputStream(tempStreamFactory.wrapTempInputStream(this.is, bufferSize));
                 advance();
-            }
-            catch (IOException e) {
+            } catch (IOException e) {
                 throw new RuntimeIOException(e);
             }
         }
@@ -556,6 +638,7 @@ public class SortingCollection<T> implements Iterable<T> {
      */
     class PeekFileRecordIterator extends PeekIterator<T> {
         final int n; // A serial number used for tie-breaking in the sort
+
         PeekFileRecordIterator(final Iterator<T> underlyingIterator, final int n) {
             super(underlyingIterator);
             this.n = n;
