@@ -18,6 +18,7 @@
 
 package htsjdk.tribble.index.interval;
 
+import htsjdk.samtools.util.IOUtil;
 import htsjdk.tribble.Feature;
 import htsjdk.tribble.index.Block;
 import htsjdk.tribble.index.Index;
@@ -60,11 +61,11 @@ public class IntervalIndexCreator extends TribbleIndexCreator {
     }
 
     public IntervalIndexCreator(final File inputFile, final int featuresPerInterval) {
-        this(inputFile.toPath(), featuresPerInterval);
+        this(IOUtil.toPath(inputFile), featuresPerInterval);
     }
 
     public IntervalIndexCreator(final File inputFile) {
-        this(inputFile.toPath());
+        this(IOUtil.toPath(inputFile));
     }
 
     public IntervalIndexCreator(final Path inputPath) {
