@@ -34,25 +34,29 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.nio.ByteBuffer;
 import java.nio.ByteOrder;
+import java.nio.channels.SeekableByteChannel;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.Set;
+import java.util.function.Function;
 
 /**
  * @author Heng Li <hengli@broadinstitute.org>
  */
 public class TabixReader {
-    private String mFn;
-    private String mIdxFn;
-    private BlockCompressedInputStream mFp;
+    private final String mFilePath;
+    private final String mIndexPath;
+    private final Function<SeekableByteChannel, SeekableByteChannel> mIndexWrapper;
+    private final BlockCompressedInputStream mFp;
 
     private int mPreset;
     private int mSc;
     private int mBc;
     private int mEc;
     private int mMeta;
+    
     //private int mSkip; (not used)
     private String[] mSeq;
 
@@ -61,6 +65,8 @@ public class TabixReader {
     private static int MAX_BIN = 37450;
     //private static int TAD_MIN_CHUNK_GAP = 32768; (not used)
     private static int TAD_LIDX_SHIFT = 14;
+    /** default buffer size for <code>readLine()</code> */
+    private static final int DEFAULT_BUFFER_SIZE = 1000;
 
     protected static class TPair64 implements Comparable<TPair64> {
         long u, v;
@@ -75,6 +81,7 @@ public class TabixReader {
             v = p.v;
         }
 
+        @Override
         public int compareTo(final TPair64 p) {
             return u == p.u ? 0 : ((u < p.u) ^ (u < 0) ^ (p.u < 0)) ? -1 : 1; // unsigned 64-bit comparison
         }
@@ -96,40 +103,64 @@ public class TabixReader {
     }
 
     /**
-     * @param fn File name of the data file
+     * @param filePath path to the data file/uri
      */
-    public TabixReader(final String fn) throws IOException {
-        this(fn, null, SeekableStreamFactory.getInstance().getBufferedStream(SeekableStreamFactory.getInstance().getStreamFor(fn)));
+    public TabixReader(final String filePath) throws IOException {
+        this(filePath, null, SeekableStreamFactory.getInstance().getBufferedStream(SeekableStreamFactory.getInstance().getStreamFor(filePath)));
     }
 
     /**
-     * @param fn File name of the data file
-     * @param idxFn Full path to the index file. Auto-generated if null
+     * @param filePath path to the of the data file/uri
+     * @param indexPath Full path to the index file. Auto-generated if null
      */
-    public TabixReader(final String fn, final String idxFn) throws IOException {
-        this(fn, idxFn, SeekableStreamFactory.getInstance().getBufferedStream(SeekableStreamFactory.getInstance().getStreamFor(fn)));
+    public TabixReader(final String filePath, final String indexPath) throws IOException {
+        this(filePath, indexPath, SeekableStreamFactory.getInstance().getBufferedStream(SeekableStreamFactory.getInstance().getStreamFor(filePath)));
     }
 
     /**
-     * @param fn File name of the data file  (used for error messages only)
+     * @param filePath path to the data file/uri
+     * @param indexPath Full path to the index file. Auto-generated if null
+     * @param wrapper a wrapper to apply to the raw byte stream of the data file if is a uri representing a {@link java.nio.file.Path}
+     * @param indexWrapper a wrapper to apply to the raw byte stream of the index file if it is a uri representing a {@link java.nio.file.Path}
+     */
+    public TabixReader(final String filePath, final String indexPath,
+                       final Function<SeekableByteChannel, SeekableByteChannel> wrapper,
+                       final Function<SeekableByteChannel, SeekableByteChannel> indexWrapper) throws IOException {
+        this(filePath, indexPath, SeekableStreamFactory.getInstance().getBufferedStream(SeekableStreamFactory.getInstance().getStreamFor(filePath, wrapper)), indexWrapper);
+    }
+
+
+    /**
+     * @param filePath Path to the data file  (used for error messages only)
      * @param stream Seekable stream from which the data is read
      */
-    public TabixReader(final String fn, SeekableStream stream) throws IOException {
-        this(fn, null, stream);
+    public TabixReader(final String filePath, SeekableStream stream) throws IOException {
+        this(filePath, null, stream);
     }
 
     /**
-     * @param fn File name of the data file  (used for error messages only)
-     * @param idxFn Full path to the index file. Auto-generated if null
+     * @param filePath Path to the data file  (used for error messages only)
+     * @param indexPath Full path to the index file. Auto-generated if null
      * @param stream Seekable stream from which the data is read
      */
-    public TabixReader(final String fn, final String idxFn, SeekableStream stream) throws IOException {
-        mFn = fn;
+    public TabixReader(final String filePath, final String indexPath, SeekableStream stream) throws IOException {
+        this(filePath, indexPath, stream, null);
+    }
+
+    /**
+     * @param filePath Path to the data file (used for error messages only)
+     * @param indexPath Full path to the index file. Auto-generated if null
+     * @param indexWrapper a wrapper to apply to the raw byte stream of the index file if it is a uri representing a {@link java.nio.file.Path}
+     * @param stream Seekable stream from which the data is read
+     */
+    public TabixReader(final String filePath, final String indexPath, SeekableStream stream, Function<SeekableByteChannel, SeekableByteChannel> indexWrapper) throws IOException {
+        mFilePath = filePath;
         mFp = new BlockCompressedInputStream(stream);
-        if(idxFn == null){
-            mIdxFn = ParsingUtils.appendToPath(fn, TabixUtils.STANDARD_INDEX_EXTENSION);
+        mIndexWrapper = indexWrapper;
+        if(indexPath == null){
+            mIndexPath = ParsingUtils.appendToPath(filePath, TabixUtils.STANDARD_INDEX_EXTENSION);
         } else {
-            mIdxFn = idxFn;
+            mIndexPath = indexPath;
         }
         readIndex();
     }
@@ -137,7 +168,7 @@ public class TabixReader {
     /** return the source (filename/URL) of that reader */
     public String getSource()
         {
-        return this.mFn;
+        return this.mFilePath;
         }
 
     private static int reg2bins(final int beg, final int _end, final int[] list) {
@@ -161,13 +192,25 @@ public class TabixReader {
     }
 
     public static long readLong(final InputStream is) throws IOException {
-        byte[] buf = new byte[8];
+        final byte[] buf = new byte[8];
         is.read(buf);
         return ByteBuffer.wrap(buf).order(ByteOrder.LITTLE_ENDIAN).getLong();
     }
 
     public static String readLine(final InputStream is) throws IOException {
-        StringBuffer buf = new StringBuffer();
+        return readLine(is, DEFAULT_BUFFER_SIZE);
+    }
+
+    /** 
+     * reads a line with a defined buffer-size 
+     * 
+     * @param is the input stream
+     * @param bufferCapacity the buffer size, must be greater than 0
+     * @return the line or null if there is no more input
+     * @throws IOException
+     */
+    private static String readLine(final InputStream is, final int bufferCapacity) throws IOException {
+        final StringBuffer buf = new StringBuffer(bufferCapacity);
         int c;
         while ((c = is.read()) >= 0 && c != '\n')
             buf.append((char) c);
@@ -175,19 +218,21 @@ public class TabixReader {
         return buf.toString();
     }
 
+    
+    
     /**
      * Read the Tabix index from a file
      *
      * @param fp File pointer
      */
-    private void readIndex(SeekableStream fp) throws IOException {
+    private void readIndex(final SeekableStream fp) throws IOException {
         if (fp == null) return;
-        BlockCompressedInputStream is = new BlockCompressedInputStream(fp);
+        final  BlockCompressedInputStream is = new BlockCompressedInputStream(fp);
         byte[] buf = new byte[4];
 
         is.read(buf, 0, 4); // read "TBI\1"
         mSeq = new String[readInt(is)]; // # sequences
-        mChr2tid = new HashMap<String, Integer>();
+        mChr2tid = new HashMap<String, Integer>( this.mSeq.length );
         mPreset = readInt(is);
         mSc = readInt(is);
         mBc = readInt(is);
@@ -202,9 +247,9 @@ public class TabixReader {
             if (buf[i] == 0) {
                 byte[] b = new byte[i - j];
                 System.arraycopy(buf, j, b, 0, b.length);
-                String s = new String(b);
-                mChr2tid.put(s, k);
-                mSeq[k++] = s;
+                final String contig = new String(b);
+                mChr2tid.put(contig, k);
+                mSeq[k++] = contig;
                 j = i + 1;
             }
         }
@@ -238,20 +283,20 @@ public class TabixReader {
      * Read the Tabix index from the default file.
      */
     private void readIndex() throws IOException {
-        ISeekableStreamFactory ssf = SeekableStreamFactory.getInstance();
-        readIndex(ssf.getBufferedStream(ssf.getStreamFor(mIdxFn), 128000));
+        final ISeekableStreamFactory ssf = SeekableStreamFactory.getInstance();
+        readIndex(ssf.getBufferedStream(ssf.getStreamFor(mIndexPath, mIndexWrapper), 128000));
     }
 
     /**
      * Read one line from the data file.
      */
     public String readLine() throws IOException {
-        return readLine(mFp);
+        return readLine(mFp, DEFAULT_BUFFER_SIZE);
     }
 
     /** return chromosome ID or -1 if it is unknown */
     public int chr2tid(final String chr) {
-        Integer tid=this.mChr2tid.get(chr);
+       final Integer tid = this.mChr2tid.get(chr);
        return tid==null?-1:tid;
     }
 
@@ -386,11 +431,10 @@ public class TabixReader {
                     ++i;
                 }
                 String s;
-                if ((s = readLine(mFp)) != null) {
+                if ((s = readLine(mFp, DEFAULT_BUFFER_SIZE)) != null) {
                     TIntv intv;
-                    char[] str = s.toCharArray();
                     curr_off = mFp.getFilePointer();
-                    if (str.length == 0 || str[0] == mMeta) continue;
+                    if (s.isEmpty() || s.charAt(0) == mMeta) continue;
                     intv = getIntv(s);
                     if (intv.tid != tid || intv.beg >= end) break; // no need to proceed
                     else if (intv.end > beg && intv.beg < end) return s; // overlap; return
@@ -488,26 +532,6 @@ public class TabixReader {
        return query(tid, start, end);
    }
 
-    public static void main(String[] args) {
-        if (args.length < 1) {
-            System.out.println("Usage: java -cp .:sam.jar TabixReader <in.gz> [region]");
-            System.exit(1);
-        }
-        try {
-            TabixReader tr = new TabixReader(args[0]);
-            String s;
-            if (args.length == 1) { // no region is specified; print the whole file
-                while ((s = tr.readLine()) != null)
-                    System.out.println(s);
-            } else { // a region is specified; random access
-                TabixReader.Iterator iter = tr.query(args[1]); // get the iterator
-                while ((s = iter.next()) != null)
-                    System.out.println(s);
-            }
-        } catch (IOException e) {
-        }
-    }
-
     // ADDED BY JTR
     public void close() {
         if(mFp != null) {
