@@ -1,5 +1,6 @@
 package htsjdk.variant.vcf;
 
+import htsjdk.samtools.util.RuntimeIOException;
 import htsjdk.tribble.util.ParsingUtils;
 import htsjdk.variant.variantcontext.Allele;
 import htsjdk.variant.variantcontext.Genotype;
@@ -9,6 +10,7 @@ import htsjdk.variant.variantcontext.LazyGenotypesContext;
 import htsjdk.variant.variantcontext.VariantContext;
 import htsjdk.variant.variantcontext.writer.IntGenotypeFieldAccessors;
 
+import java.io.IOException;
 import java.lang.reflect.Array;
 import java.nio.charset.Charset;
 import java.util.ArrayList;
@@ -64,15 +66,42 @@ public class VCFEncoder {
         this.allowMissingFieldsInHeader = allow;
     }
 
+    /**
+     * encodes a {@link VariantContext} as a VCF line
+     *
+     * Depending on the use case it may be more efficient to {@link #write(Appendable, VariantContext)} directly
+     * instead of creating an intermediate string.
+     *
+     * @return the VCF line
+     */
     public String encode(final VariantContext context) {
+        try {
+            final StringBuilder stringBuilder = new StringBuilder(1000);
+            write(stringBuilder, context);
+            return stringBuilder.toString();
+        } catch (final IOException error) {
+            throw new RuntimeIOException("Cannot encode variant", error);
+        }
+    }
+
+
+    /**
+     * encodes a {@link VariantContext} context as VCF, and writes it directly to an {@link Appendable}
+     *
+     * This may be more efficient than calling {@link #encode(VariantContext)} and then writing the result since it
+     * avoids creating an intermediate string.
+     *
+     * @param vcfOutput the {@link Appendable} to write to
+     * @param context the variant
+     * @return the java.lang.Appendable 'vcfOutput'
+     * @throws IOException
+     */
+    public void write(final Appendable vcfOutput, final VariantContext context) throws IOException {
         if (this.header == null) {
             throw new NullPointerException("The header field must be set on the VCFEncoder before encoding records.");
         }
-
-        final StringBuilder stringBuilder = new StringBuilder();
-
         // CHROM
-        stringBuilder.append(context.getContig()).append(VCFConstants.FIELD_SEPARATOR)
+        vcfOutput.append(context.getContig()).append(VCFConstants.FIELD_SEPARATOR)
                 // POS
                 .append(String.valueOf(context.getStart())).append(VCFConstants.FIELD_SEPARATOR)
                 // ID
@@ -81,27 +110,27 @@ public class VCFEncoder {
                 .append(context.getReference().getDisplayString()).append(VCFConstants.FIELD_SEPARATOR);
 
         // ALT
-        if (context.isVariant()) {
+        if ( context.isVariant() ) {
             Allele altAllele = context.getAlternateAllele(0);
             String alt = altAllele.getDisplayString();
-            stringBuilder.append(alt);
+            vcfOutput.append(alt);
 
             for (int i = 1; i < context.getAlternateAlleles().size(); i++) {
                 altAllele = context.getAlternateAllele(i);
                 alt = altAllele.getDisplayString();
-                stringBuilder.append(',');
-                stringBuilder.append(alt);
+                vcfOutput.append(',');
+                vcfOutput.append(alt);
             }
         } else {
-            stringBuilder.append(VCFConstants.EMPTY_ALTERNATE_ALLELE_FIELD);
+            vcfOutput.append(VCFConstants.EMPTY_ALTERNATE_ALLELE_FIELD);
         }
 
-        stringBuilder.append(VCFConstants.FIELD_SEPARATOR);
+        vcfOutput.append(VCFConstants.FIELD_SEPARATOR);
 
         // QUAL
-        if (!context.hasLog10PError()) stringBuilder.append(VCFConstants.MISSING_VALUE_v4);
-        else stringBuilder.append(formatQualValue(context.getPhredScaledQual()));
-        stringBuilder.append(VCFConstants.FIELD_SEPARATOR)
+        if ( ! context.hasLog10PError()) vcfOutput.append(VCFConstants.MISSING_VALUE_v4);
+        else vcfOutput.append(formatQualValue(context.getPhredScaledQual()));
+        vcfOutput.append(VCFConstants.FIELD_SEPARATOR)
                 // FILTER
                 .append(getFilterString(context)).append(VCFConstants.FIELD_SEPARATOR);
 
@@ -114,31 +143,31 @@ public class VCFEncoder {
             final String outputValue = formatVCFField(field.getValue());
             if (outputValue != null) infoFields.put(field.getKey(), outputValue);
         }
-        writeInfoString(infoFields, stringBuilder);
+        writeInfoString(infoFields, vcfOutput);
 
         // FORMAT
         final GenotypesContext gc = context.getGenotypes();
         if (gc.isLazyWithData() && ((LazyGenotypesContext) gc).getUnparsedGenotypeData() instanceof String) {
-            stringBuilder.append(VCFConstants.FIELD_SEPARATOR);
-            stringBuilder.append(((LazyGenotypesContext) gc).getUnparsedGenotypeData().toString());
+            vcfOutput.append(VCFConstants.FIELD_SEPARATOR);
+            vcfOutput.append(((LazyGenotypesContext) gc).getUnparsedGenotypeData().toString());
         } else {
             final List<String> genotypeAttributeKeys = context.calcVCFGenotypeKeys(this.header);
-            if (!genotypeAttributeKeys.isEmpty()) {
+            if ( ! genotypeAttributeKeys.isEmpty()) {
                 for (final String format : genotypeAttributeKeys)
-                    if (!this.header.hasFormatLine(format))
+                    if ( ! this.header.hasFormatLine(format))
                         fieldIsMissingFromHeaderError(context, format, "FORMAT");
 
                 final String genotypeFormatString = ParsingUtils.join(VCFConstants.GENOTYPE_FIELD_SEPARATOR, genotypeAttributeKeys);
 
-                stringBuilder.append(VCFConstants.FIELD_SEPARATOR);
-                stringBuilder.append(genotypeFormatString);
+                vcfOutput.append(VCFConstants.FIELD_SEPARATOR);
+                vcfOutput.append(genotypeFormatString);
 
                 final Map<Allele, String> alleleStrings = buildAlleleStrings(context);
-                addGenotypeData(context, alleleStrings, genotypeAttributeKeys, stringBuilder);
+                appendGenotypeData(context, alleleStrings, genotypeAttributeKeys, vcfOutput);
             }
         }
 
-        return stringBuilder.toString();
+
     }
 
     VCFHeader getVCFHeader() {
@@ -160,7 +189,7 @@ public class VCFEncoder {
         else return VCFConstants.UNFILTERED;
     }
 
-    private String formatQualValue(final double qual) {
+    private static String formatQualValue(final double qual) {
         String s = String.format(QUAL_FORMAT_STRING, qual);
         if (s.endsWith(QUAL_FORMAT_EXTENSION_TO_TRIM))
             s = s.substring(0, s.length() - QUAL_FORMAT_EXTENSION_TO_TRIM.length());
@@ -170,27 +199,28 @@ public class VCFEncoder {
     private void fieldIsMissingFromHeaderError(final VariantContext vc, final String id, final String field) {
         if (!allowMissingFieldsInHeader)
             throw new IllegalStateException("Key " + id + " found in VariantContext field " + field
-                    + " at " + vc.getContig() + ":" + vc.getStart()
-                    + " but this key isn't defined in the VCFHeader.  We require all VCFs to have"
-                    + " complete VCF headers by default.");
+                                                    + " at " + vc.getContig() + ":" + vc.getStart()
+                                                    + " but this key isn't defined in the VCFHeader.  We require all VCFs to have"
+                                                    + " complete VCF headers by default.");
     }
 
+    @SuppressWarnings("rawtypes")
     String formatVCFField(final Object val) {
         final String result;
-        if (val == null)
+        if ( val == null )
             result = VCFConstants.MISSING_VALUE_v4;
-        else if (val instanceof Double)
+        else if ( val instanceof Double )
             result = formatVCFDouble((Double) val);
-        else if (val instanceof Boolean)
-            result = (Boolean) val ? "" : null; // empty string for true, null for false
-        else if (val instanceof List) {
-            result = formatVCFField(((List) val).toArray());
-        } else if (val.getClass().isArray()) {
+        else if ( val instanceof Boolean )
+            result = (Boolean)val ? "" : null; // empty string for true, null for false
+        else if ( val instanceof List ) {
+            result = formatVCFField(((List)val).toArray());
+        } else if ( val.getClass().isArray() ) {
             final int length = Array.getLength(val);
-            if (length == 0)
+            if ( length == 0 )
                 return formatVCFField(null);
             final StringBuilder sb = new StringBuilder(formatVCFField(Array.get(val, 0)));
-            for (int i = 1; i < length; i++) {
+            for ( int i = 1; i < length; i++) {
                 sb.append(',');
                 sb.append(formatVCFField(Array.get(val, i)));
             }
@@ -248,25 +278,40 @@ public class VCFEncoder {
      * Add the genotype data
      */
     public void addGenotypeData(final VariantContext vc, final Map<Allele, String> alleleMap, final List<String> genotypeFormatKeys, final StringBuilder builder) {
-        final int ploidy = vc.getMaxPloidy(2);
+        try {
+            appendGenotypeData(vc,alleleMap,genotypeFormatKeys,builder);
+        } catch (final IOException err) {
+            throw new RuntimeIOException("addGenotypeData failed",err);
+        }
+    }
+
+    /**
+     * Add the genotype Data to a java.lang.Appendable
+     * @param vc the variant
+     * @param alleleMap
+     * @param genotypeFormatKeys
+     * @param vcfoutput VCF output
+     * @throws IOException
+     */
+    private void appendGenotypeData(final VariantContext vc, final Map<Allele, String> alleleMap, final List<String> genotypeFormatKeys, final Appendable vcfoutput) throws IOException {final int ploidy = vc.getMaxPloidy(2);
 
         for (final String sample : this.header.getGenotypeSamples()) {
-            builder.append(VCFConstants.FIELD_SEPARATOR);
+            vcfoutput.append(VCFConstants.FIELD_SEPARATOR);
 
             Genotype g = vc.getGenotype(sample);
             if (g == null) g = GenotypeBuilder.createMissing(sample, ploidy);
 
-            final List<String> attrs = new ArrayList<String>(genotypeFormatKeys.size());
+            final List<String> attrs = new ArrayList<>(genotypeFormatKeys.size());
             for (final String field : genotypeFormatKeys) {
                 if (field.equals(VCFConstants.GENOTYPE_KEY)) {
                     if (!g.isAvailable()) {
                         throw new IllegalStateException("GTs cannot be missing for some samples if they are available for others in the record");
                     }
 
-                    writeAllele(g.getAllele(0), alleleMap, builder);
+                    writeAllele(g.getAllele(0), alleleMap, vcfoutput);
                     for (int i = 1; i < g.getPloidy(); i++) {
-                        builder.append(g.isPhased() ? VCFConstants.PHASED : VCFConstants.UNPHASED);
-                        writeAllele(g.getAllele(i), alleleMap, builder);
+                        vcfoutput.append(g.isPhased() ? VCFConstants.PHASED : VCFConstants.UNPHASED);
+                        writeAllele(g.getAllele(i), alleleMap, vcfoutput);
                     }
                     continue;
 
@@ -328,10 +373,10 @@ public class VCFEncoder {
             }
 
             for (int i = 0; i < attrs.size(); i++) {
-                if (i > 0 || genotypeFormatKeys.contains(VCFConstants.GENOTYPE_KEY)) {
-                    builder.append(VCFConstants.GENOTYPE_FIELD_SEPARATOR);
+                if ( i > 0 || genotypeFormatKeys.contains(VCFConstants.GENOTYPE_KEY)) {
+                    vcfoutput.append(VCFConstants.GENOTYPE_FIELD_SEPARATOR);
                 }
-                builder.append(attrs.get(i));
+                vcfoutput.append(attrs.get(i));
             }
         }
     }
@@ -339,24 +384,24 @@ public class VCFEncoder {
     /*
      * Create the info string; assumes that no values are null
      */
-    private void writeInfoString(final Map<String, String> infoFields, final StringBuilder builder) {
-        if (infoFields.isEmpty()) {
-            builder.append(VCFConstants.EMPTY_INFO_FIELD);
+    private void writeInfoString(final Map<String, String> infoFields, final Appendable vcfoutput) throws IOException {
+        if ( infoFields.isEmpty() ) {
+            vcfoutput.append(VCFConstants.EMPTY_INFO_FIELD);
             return;
         }
 
         boolean isFirst = true;
         for (final Map.Entry<String, String> entry : infoFields.entrySet()) {
             if (isFirst) isFirst = false;
-            else builder.append(VCFConstants.INFO_FIELD_SEPARATOR);
+            else vcfoutput.append(VCFConstants.INFO_FIELD_SEPARATOR);
 
-            builder.append(entry.getKey());
+            vcfoutput.append(entry.getKey());
 
-            if (!entry.getValue().equals("")) {
+            if ( ! entry.getValue().isEmpty()) {
                 final VCFInfoHeaderLine metaData = this.header.getInfoHeaderLine(entry.getKey());
-                if (metaData == null || metaData.getCountType() != VCFHeaderLineCount.INTEGER || metaData.getCount() != 0) {
-                    builder.append('=');
-                    builder.append(entry.getValue());
+                if ( metaData == null || metaData.getCountType() != VCFHeaderLineCount.INTEGER || metaData.getCount() != 0 ) {
+                    vcfoutput.append('=');
+                    vcfoutput.append(entry.getValue());
                 }
             }
         }
@@ -374,10 +419,11 @@ public class VCFEncoder {
         return alleleMap;
     }
 
-    private void writeAllele(final Allele allele, final Map<Allele, String> alleleMap, final StringBuilder builder) {
+    private static void writeAllele(final Allele allele, final Map<Allele, String> alleleMap, final Appendable vcfOutput) throws IOException {
         final String encoding = alleleMap.get(allele);
-        if (encoding == null)
+        if (encoding == null) {
             throw new RuntimeException("Allele " + allele + " is not an allele in the variant context");
-        builder.append(encoding);
+        }
+        vcfOutput.append(encoding);
     }
 }
