@@ -1,5 +1,6 @@
 package htsjdk.samtools;
 
+import htsjdk.HtsjdkTest;
 import htsjdk.samtools.cram.CRAIEntry;
 import htsjdk.samtools.cram.build.CramContainerIterator;
 import htsjdk.samtools.cram.ref.ReferenceSource;
@@ -17,12 +18,12 @@ import java.util.List;
  * Companion to CRAMBAIIndexerTest, for testing CRAI indices created on cram
  * streams;
  */
-public class CRAMCRAIIndexerTest {
+public class CRAMCRAIIndexerTest extends HtsjdkTest {
 
     @Test
     public void testCRAIIndexerFromContainer() throws IOException {
         final File CRAMFile = new File("src/test/resources/htsjdk/samtools/cram/test2.cram");
-        final File refFile = new File("src/test/resources/htsjdk/samtools/cram/test2.fa");
+        final File refFile = new File("src/test/resources/htsjdk/samtools/cram/auxf.fa");
         ReferenceSource refSource = new ReferenceSource(refFile);
         CRAMFileReader reader = new CRAMFileReader(
                 CRAMFile,
@@ -55,7 +56,7 @@ public class CRAMCRAIIndexerTest {
     @Test
     public void testCRAIIndexerFromStream() throws IOException {
         final File CRAMFile = new File("src/test/resources/htsjdk/samtools/cram/test2.cram");
-        final File refFile = new File("src/test/resources/htsjdk/samtools/cram/test2.fa");
+        final File refFile = new File("src/test/resources/htsjdk/samtools/cram/auxf.fa");
         ReferenceSource refSource = new ReferenceSource(refFile);
 
         // get the header to use
@@ -180,4 +181,4 @@ public class CRAMCRAIIndexerTest {
         return count;
     }
 
-}
\ No newline at end of file
+}
