@@ -337,7 +337,7 @@ public class SAMFileWriterFactoryTest extends HtsjdkTest {
             Files.deleteIfExists(outputPath);
             final SAMFileHeader header = new SAMFileHeader();
             final SAMFileWriterFactory factory = createWriterFactoryWithOptions(header);
-            final File referenceFile = new File(TEST_DATA_DIR, "hg19mini.fasta");
+            final Path referenceFile = new File(TEST_DATA_DIR, "hg19mini.fasta").toPath();
 
             int nRecs;
             try (final SAMFileWriter samWriter = factory.makeWriter(header, false, outputPath, referenceFile)) {
@@ -347,6 +347,24 @@ public class SAMFileWriterFactoryTest extends HtsjdkTest {
         }
     }
 
+    @Test(dataProvider="bamOrCramWriter")
+    public void testMakeWriterPathAndReferencePath(String extension) throws Exception {
+        final String referenceName = "hg19mini.fasta";
+        try (FileSystem jimfs = Jimfs.newFileSystem(Configuration.unix())) {
+            Path outputPath = jimfs.getPath("testMakeWriterPath" + extension);
+            Files.deleteIfExists(outputPath);
+            final SAMFileHeader header = new SAMFileHeader();
+            final SAMFileWriterFactory factory = createWriterFactoryWithOptions(header);
+            final Path referencePath = jimfs.getPath(referenceName);
+            Files.copy(new File(TEST_DATA_DIR, referenceName).toPath(), referencePath);
+
+            int nRecs;
+            try (final SAMFileWriter samWriter = factory.makeWriter(header, false, outputPath, referencePath)) {
+                nRecs = fillSmallBam(samWriter);
+            }
+            verifyWriterOutput(outputPath, new ReferenceSource(referencePath), nRecs, true);
+        }
+    }
 
     @Test
     public void testMakeCRAMWriterWithOptions() throws Exception {
