@@ -3,6 +3,7 @@ package htsjdk.samtools;
 import java.nio.file.Path;
 
 import htsjdk.HtsjdkTest;
+import htsjdk.samtools.util.IOUtil;
 import org.testng.Assert;
 import org.testng.annotations.DataProvider;
 import org.testng.annotations.Test;
@@ -88,6 +89,6 @@ public class SamFilesTest extends HtsjdkTest {
     @Test(dataProvider ="filesAndIndicies")
     public void testIndexSymlinking(File bam, File expected_index) {
         Assert.assertEquals(SamFiles.findIndex(bam), expected_index);
-        Assert.assertEquals(SamFiles.findIndex(bam.toPath()), expected_index == null ? null : expected_index.toPath());
+        Assert.assertEquals(SamFiles.findIndex(bam.toPath()), IOUtil.toPath(expected_index));
     }
 }
