@@ -1,13 +1,14 @@
 package htsjdk.samtools.metrics;
 
 
+import htsjdk.HtsjdkTest;
 import htsjdk.samtools.util.TestUtil;
 import org.testng.Assert;
 import org.testng.annotations.Test;
 
 import java.io.IOException;
 
-public class StringHeaderTest {
+public class StringHeaderTest extends HtsjdkTest {
 
     @Test
     public void testStringHeaderSerialization() throws IOException, ClassNotFoundException {
@@ -16,4 +17,4 @@ public class StringHeaderTest {
         Assert.assertEquals(deserializedHeader, header);
     }
 
-}
\ No newline at end of file
+}
