@@ -25,23 +25,18 @@
 package htsjdk.samtools.util;
 
 import htsjdk.HtsjdkTest;
-import htsjdk.samtools.*;
+import htsjdk.samtools.SAMException;
+import htsjdk.samtools.SAMFileHeader;
+import htsjdk.samtools.SAMSequenceRecord;
 import htsjdk.variant.vcf.VCFFileReader;
 import org.testng.Assert;
-import org.testng.annotations.BeforeTest;
 import org.testng.annotations.DataProvider;
 import org.testng.annotations.Test;
 
 import java.io.File;
-import java.nio.file.Paths;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.LinkedList;
-import java.util.List;
-import java.util.SortedSet;
-import java.util.TreeSet;
+import java.io.IOException;
+import java.nio.file.Path;
+import java.util.*;
 
 /**
  * Tests the IntervalList class
@@ -50,9 +45,10 @@ public class IntervalListTest extends HtsjdkTest {
 
     final SAMFileHeader fileHeader;
     final IntervalList list1, list2, list3;
+    static final public Path TEST_DIR = new File("src/test/resources/htsjdk/samtools/intervallist").toPath();
 
     public IntervalListTest() {
-        fileHeader = IntervalList.fromFile(new File("src/test/resources/htsjdk/samtools/intervallist/IntervalListchr123_empty.interval_list")).getHeader();
+        fileHeader = IntervalList.fromPath(TEST_DIR.resolve("IntervalListchr123_empty.interval_list")).getHeader();
         fileHeader.setSortOrder(SAMFileHeader.SortOrder.unsorted);
 
         list1 = new IntervalList(fileHeader);
@@ -76,11 +72,12 @@ public class IntervalListTest extends HtsjdkTest {
         list3.add(new Interval("3", 50, 470));
     }
 
+
     @Test
-    public void testIntervalListFrom() {
-        final String testPath = "src/test/resources/htsjdk/samtools/intervallist/IntervalListFromVCFTestComp.interval_list";
+    public void testIntervalListFrom() throws IOException {
+        final String testPath = TEST_DIR.resolve("IntervalListFromVCFTestComp.interval_list").toString();
         final IntervalList fromFileList = IntervalList.fromFile(new File(testPath));
-        final IntervalList fromPathList = IntervalList.fromPath(Paths.get(testPath));
+        final IntervalList fromPathList = IntervalList.fromPath(IOUtil.getPath(testPath));
         fromFileList.getHeader().getSequenceDictionary().assertSameDictionary(fromPathList.getHeader().getSequenceDictionary());
         Assert.assertEquals(CollectionUtil.makeCollection(fromFileList.iterator()), CollectionUtil.makeCollection(fromPathList.iterator()));
     }
@@ -225,18 +222,16 @@ public class IntervalListTest extends HtsjdkTest {
         union13.add(new Interval("2", 200, 600));
         union13.add(new Interval("3", 50, 470));
 
+
         return new Object[][]{
                 new Object[]{Arrays.asList(list1, list2, list3), union123},
                 new Object[]{Arrays.asList(list1, list2), union12},
-                new Object[]{Arrays.asList(list1, list2), union12},
-                new Object[]{Arrays.asList(list2, list3), union23},
                 new Object[]{Arrays.asList(list2, list3), union23},
                 new Object[]{Arrays.asList(list1, list3), union13},
-                new Object[]{Arrays.asList(list1, list3), union13}
         };
     }
 
-    @Test(dataProvider = "unionData", enabled = true)
+    @Test(dataProvider = "unionData")
     public void testUnionIntervalLists(final List<IntervalList> lists, final IntervalList list) {
         Assert.assertEquals(
                 CollectionUtil.makeCollection(IntervalList.union(lists).iterator()),
@@ -467,22 +462,23 @@ public class IntervalListTest extends HtsjdkTest {
 
     @DataProvider(name = "VCFCompData")
     public Object[][] VCFCompData() {
+        final Path intervalListFromVcf = TEST_DIR.resolve("IntervalListFromVCFTest.vcf");
+        final Path intervalListFromVcfManual = TEST_DIR.resolve("IntervalListFromVCFTestManual.vcf");
+
         return new Object[][]{
-                new Object[]{"src/test/resources/htsjdk/samtools/intervallist/IntervalListFromVCFTest.vcf", "src/test/resources/htsjdk/samtools/intervallist/IntervalListFromVCFTestComp.interval_list", false},
-                new Object[]{"src/test/resources/htsjdk/samtools/intervallist/IntervalListFromVCFTest.vcf", "src/test/resources/htsjdk/samtools/intervallist/IntervalListFromVCFTestCompInverse.interval_list", true},
-                new Object[]{"src/test/resources/htsjdk/samtools/intervallist/IntervalListFromVCFTestManual.vcf", "src/test/resources/htsjdk/samtools/intervallist/IntervalListFromVCFTestManualComp.interval_list", false},
-                new Object[]{"src/test/resources/htsjdk/samtools/intervallist/IntervalListFromVCFTestManual.vcf", "src/test/resources/htsjdk/samtools/intervallist/IntervalListFromVCFTestCompInverseManual.interval_list", true}
+                new Object[]{intervalListFromVcf, TEST_DIR.resolve("IntervalListFromVCFTestComp.interval_list"), false},
+                new Object[]{intervalListFromVcf, TEST_DIR.resolve("IntervalListFromVCFTestCompInverse.interval_list"), true},
+                new Object[]{intervalListFromVcfManual, TEST_DIR.resolve("IntervalListFromVCFTestManualComp.interval_list"), false},
+                new Object[]{intervalListFromVcfManual, TEST_DIR.resolve("IntervalListFromVCFTestCompInverseManual.interval_list"), true}
         };
     }
 
     @Test(dataProvider = "VCFCompData")
-    public void testFromVCF(final String vcf, final String compInterval, final boolean invertVCF) {
+    public void testFromVCF(final Path vcf, final Path compInterval, final boolean invertVCF) {
 
-        final File vcfFile = new File(vcf);
-        final File compIntervalFile = new File(compInterval);
 
-        final IntervalList compList = IntervalList.fromFile(compIntervalFile);
-        final IntervalList list = invertVCF ? IntervalList.invert(VCFFileReader.toIntervalList(vcfFile.toPath())) : VCFFileReader.toIntervalList(vcfFile.toPath());
+        final IntervalList compList = IntervalList.fromPath(compInterval);
+        final IntervalList list = invertVCF ? IntervalList.invert(VCFFileReader.toIntervalList(vcf)) : VCFFileReader.toIntervalList(vcf);
 
         compList.getHeader().getSequenceDictionary().assertSameDictionary(list.getHeader().getSequenceDictionary());
 
@@ -492,8 +488,8 @@ public class IntervalListTest extends HtsjdkTest {
         //assert that the intervals correspond
         Assert.assertEquals(intervals, compIntervals);
 
-        final List<String> intervalNames = new LinkedList<String>();
-        final List<String> compIntervalNames = new LinkedList<String>();
+        final List<String> intervalNames = new LinkedList<>();
+        final List<String> compIntervalNames = new LinkedList<>();
 
         for (final Interval interval : intervals) {
             intervalNames.add(interval.getName());
@@ -507,13 +503,11 @@ public class IntervalListTest extends HtsjdkTest {
 
 
     @Test(dataProvider = "VCFCompData")
-    public void testFromVCFWithPath(final String vcf, final String compInterval, final boolean invertVCF) {
+    public void testFromVCFWithPath(final Path vcf, final Path compInterval, final boolean invertVCF) {
 
-        final File vcfFile = new File(vcf);
-        final File compIntervalFile = new File(compInterval);
 
-        final IntervalList compList = IntervalList.fromFile(compIntervalFile);
-        final IntervalList list = invertVCF ? IntervalList.invert(VCFFileReader.toIntervalList(vcfFile.toPath())) : VCFFileReader.toIntervalList(vcfFile.toPath());
+        final IntervalList compList = IntervalList.fromPath(compInterval);
+        final IntervalList list = invertVCF ? IntervalList.invert(VCFFileReader.toIntervalList(vcf)) : VCFFileReader.toIntervalList(vcf);
 
         compList.getHeader().getSequenceDictionary().assertSameDictionary(list.getHeader().getSequenceDictionary());
 
@@ -523,8 +517,8 @@ public class IntervalListTest extends HtsjdkTest {
         //assert that the intervals correspond
         Assert.assertEquals(intervals, compIntervals);
 
-        final List<String> intervalNames = new LinkedList<String>();
-        final List<String> compIntervalNames = new LinkedList<String>();
+        final List<String> intervalNames = new LinkedList<>();
+        final List<String> compIntervalNames = new LinkedList<>();
 
         for (final Interval interval : intervals) {
             intervalNames.add(interval.getName());
@@ -539,17 +533,18 @@ public class IntervalListTest extends HtsjdkTest {
 
     @DataProvider
     public Object[][] testFromSequenceData() {
+        final Path intervalList = TEST_DIR.resolve("IntervalListFromVCFTestComp.interval_list");
         return new Object[][]{
-                new Object[]{"src/test/resources/htsjdk/samtools/intervallist/IntervalListFromVCFTestComp.interval_list", "1", 249250621},
-                new Object[]{"src/test/resources/htsjdk/samtools/intervallist/IntervalListFromVCFTestComp.interval_list", "2", 243199373},
-                new Object[]{"src/test/resources/htsjdk/samtools/intervallist/IntervalListFromVCFTestComp.interval_list", "3", 198022430},
+                new Object[]{intervalList, "1", 249250621},
+                new Object[]{intervalList, "2", 243199373},
+                new Object[]{intervalList, "3", 198022430},
         };
     }
 
     @Test(dataProvider = "testFromSequenceData")
-    public void testFromSequenceName(final String intervalList, final String referenceName, final Integer length) {
+    public void testFromSequenceName(final Path intervalList, final String referenceName, final Integer length) {
 
-        final IntervalList intervals = IntervalList.fromFile(new File(intervalList));
+        final IntervalList intervals = IntervalList.fromPath(intervalList);
         final IntervalList test = IntervalList.fromName(intervals.getHeader(), referenceName);
         Assert.assertEquals(test.getIntervals(), CollectionUtil.makeList(new Interval(referenceName, 1, length)));
     }
@@ -659,8 +654,24 @@ public class IntervalListTest extends HtsjdkTest {
 
     @Test(expectedExceptions = IllegalArgumentException.class)
     public void testContigsAbsentInHeader() {
-        String vcf = "src/test/resources/htsjdk/samtools/intervallist/IntervalListFromVCFNoContigLines.vcf";
+        String vcf = TEST_DIR.resolve("IntervalListFromVCFNoContigLines.vcf").toString();
         final File vcfFile = new File(vcf);
         VCFFileReader.toIntervalList(vcfFile.toPath());
     }
+
+
+    @DataProvider
+    public static Object[][] brokenFiles() {
+        return new Object[][]{
+                {TEST_DIR.resolve("broken.end.extends.too.far.interval_list")},
+                {TEST_DIR.resolve("broken.start.bigger.than.end.interval_list")},
+                {TEST_DIR.resolve("broken.unallowed.strand.interval_list")},
+                {TEST_DIR.resolve("broken.zero.start.interval_list")},
+        };
+    }
+
+    @Test(dataProvider = "brokenFiles", expectedExceptions = IllegalArgumentException.class)
+    public void testBreaks(final Path brokenIntervalFile){
+        IntervalList.fromPath(brokenIntervalFile);
+    }
 }
