@@ -23,8 +23,8 @@
  */
 package htsjdk.samtools.util;
 
+import htsjdk.HtsjdkTest;
 import htsjdk.samtools.*;
-import htsjdk.samtools.reference.ReferenceSequence;
 import htsjdk.samtools.reference.ReferenceSequenceFile;
 import htsjdk.samtools.reference.ReferenceSequenceFileFactory;
 import org.testng.Assert;
@@ -32,14 +32,12 @@ import org.testng.annotations.DataProvider;
 import org.testng.annotations.Test;
 
 import java.io.File;
-import java.util.Arrays;
-import java.util.HashSet;
-import java.util.Set;
+import java.util.*;
 
 /**
  * @author alecw@broadinstitute.org
  */
-public class SequenceUtilTest {
+public class SequenceUtilTest extends HtsjdkTest {
     private static final String HEADER = "@HD\tVN:1.0\tSO:unsorted\n";
     private static final String SEQUENCE_NAME=
         "@SQ\tSN:phix174.seq\tLN:5386\tUR:/seq/references/PhiX174/v0/PhiX174.fasta\tAS:PhiX174\tM5:3332ed720ac7eaa9b3655c06f6b9e196";
@@ -61,7 +59,7 @@ public class SequenceUtilTest {
 
         return new Object[][]{ {makeSequenceDictionary(5386, "/seq/references/PhiX174/v0/PhiX174.fasta",
                 "3332ed720ac7eaa9b3655c06f6b9e196"),
-                new SAMTextHeaderCodec().decode(new StringLineReader(s), null).getSequenceDictionary()}};
+                new SAMTextHeaderCodec().decode(BufferedLineReader.fromString(s), null).getSequenceDictionary()}};
     }
 
     @Test(dataProvider = "compatibleNonEqualLists")
@@ -105,7 +103,7 @@ public class SequenceUtilTest {
     private SAMSequenceDictionary makeSequenceDictionary(final int length, final String ur, final String m5) {
         final String s = HEADER +
                 String.format("@SQ\tSN:phix174.seq\tLN:%d\tUR:%s\tAS:PhiX174\tM5:%s\n", length, ur, m5);
-        return new SAMTextHeaderCodec().decode(new StringLineReader(s), null).getSequenceDictionary();
+        return new SAMTextHeaderCodec().decode(BufferedLineReader.fromString(s), null).getSequenceDictionary();
     }
 
     @Test(dataProvider = "makeReferenceFromAlignment")
@@ -144,6 +142,11 @@ public class SequenceUtilTest {
         final SAMRecord rec = new SAMRecord(null);
         rec.setReadName("test");
         rec.setReadString(readString);
+        final byte[] byteArray = new byte[readString.length()];
+
+        Arrays.fill(byteArray, (byte)33);
+
+        rec.setBaseQualities(byteArray);
         rec.setCigarString(cigar);
 
         final byte[] refBases = StringUtil.stringToBytes(reference);
@@ -151,6 +154,9 @@ public class SequenceUtilTest {
         final int nExact = SequenceUtil.countMismatches(rec, refBases, -1, false, false);
         Assert.assertEquals(nExact, expectedMismatchesExact);
 
+        final int sumMismatchesQualityExact = SequenceUtil.sumQualitiesOfMismatches(rec, refBases, -1, false);
+        Assert.assertEquals(sumMismatchesQualityExact, expectedMismatchesExact * 33);
+
         final int nAmbiguous = SequenceUtil.countMismatches(rec, refBases, -1, false, true);
         Assert.assertEquals(nAmbiguous, expectedMismatchesAmbiguous);
     }
@@ -175,6 +181,58 @@ public class SequenceUtilTest {
         };
     }
 
+    @DataProvider(name="mismatchBisulfiteCountsDataProvider")
+    public Object[][] mismatchBisulfiteCountsDataProvider() {
+
+        List<Object[]> tests = new ArrayList<>();
+        final List<String> bases = Arrays.asList("A","C","T","G");
+
+        for (final String base : bases) {
+            for (final String ref : bases) {
+                for (final Boolean strand : Arrays.asList(true, false)) {
+
+                    final Integer count;
+
+                    if (base.equals(ref)) count = 0;
+                    else if (base.equals("A") && ref.equals("G") && !strand) count = 0;
+                    else if (base.equals("T") && ref.equals("C") &&  strand) count = 0;
+                    else count = 1;
+
+                    tests.add(new Object[]{base, "1M", ref, strand, count});
+
+                }
+            }
+        }
+        return tests.toArray(new Object[1][]);
+    }
+
+
+    @Test(dataProvider = "mismatchBisulfiteCountsDataProvider")
+    public void testMismatchBisulfiteCounts(final String readString, final String cigar, final String reference,
+                                            final boolean positiveStrand, final int expectedMismatches) {
+
+        final byte baseQuality = 30;
+        final SAMRecord rec = new SAMRecord(null);
+        rec.setReadName("test");
+        rec.setReadString(readString);
+        rec.setReadNegativeStrandFlag(!positiveStrand);
+        final byte[] byteArray = new byte[readString.length()];
+
+        Arrays.fill(byteArray,baseQuality);
+
+        rec.setBaseQualities(byteArray);
+        rec.setCigarString(cigar);
+
+        final byte[] refBases = StringUtil.stringToBytes(reference);
+
+        final int nExact = SequenceUtil.countMismatches(rec, refBases, -1, true, false);
+        Assert.assertEquals(nExact, expectedMismatches);
+
+        final int sumMismatchesQualityExact = SequenceUtil.sumQualitiesOfMismatches(rec, refBases, -1, true);
+        Assert.assertEquals(sumMismatchesQualityExact, expectedMismatches * baseQuality);
+
+    }
+
     @Test(dataProvider = "countInsertedAndDeletedBasesTestCases")
     public void testCountInsertedAndDeletedBases(final String cigarString, final int insertedBases, final int deletedBases) {
         final Cigar cigar = TextCigarCodec.decode(cigarString);
@@ -204,11 +262,11 @@ public class SequenceUtilTest {
 
     @Test(dataProvider = "testKmerGenerationTestCases")
     public void testKmerGeneration(final int length, final String[] expectedKmers) {
-        final Set<String> actualSet = new HashSet<String>();
+        final Set<String> actualSet = new HashSet<>();
         for (final byte[] kmer : SequenceUtil.generateAllKmers(length)) {
             actualSet.add(StringUtil.bytesToString(kmer));
         }
-        final Set<String> expectedSet = new HashSet<String>(Arrays.asList(expectedKmers));
+        final Set<String> expectedSet = new HashSet<>(Arrays.asList(expectedKmers));
         Assert.assertTrue(actualSet.equals(expectedSet));
     }
 
@@ -450,4 +508,115 @@ public class SequenceUtilTest {
             }
         });
     }
+
+    @DataProvider(name = "testNmFromCigarProvider")
+    Object[][] testNmFromCigar() {
+        return new Object[][]{
+                {"1M", 0},
+                {"1S1D", 1},
+                {"1H3X", 3},
+                {"1H5=3M2X", 2},
+                {"5P5M", 0},
+                {"5S8I", 8}
+        };
+    }
+
+    @Test(dataProvider = "testNmFromCigarProvider")
+    public void testNmTagFromCigar(final String cigarString, final int expectedNmValue) {
+        final SAMRecord rec = new SAMRecord(null);
+        rec.setReadName("test");
+        rec.setCigarString(cigarString);
+
+        Assert.assertEquals(SequenceUtil.calculateSamNmTagFromCigar(rec),expectedNmValue);
+    }
+
+    @Test
+    public void testReverseComplement() {
+        Assert.assertEquals(SequenceUtil.reverseComplement("ABCDEFGHIJKLMNOPQRSTUVWXYZ"),"ZYXWVUASRQPONMLKJIHCFEDGBT");
+        Assert.assertEquals(SequenceUtil.reverseComplement("abcdefghijklmnopqrstuvwxy"),"yxwvuasrqponmlkjihcfedgbt"); //missing "z" on purpose so that we test both even-lengthed and odd-lengthed strings
+    }
+
+    @Test
+    public void testUpperCase() {
+        Assert.assertEquals(SequenceUtil.upperCase(StringUtil.stringToBytes("ABCDEFGHIJKLMNOPQRSTUVWXYZ")), StringUtil.stringToBytes("ABCDEFGHIJKLMNOPQRSTUVWXYZ"));
+        Assert.assertEquals(SequenceUtil.upperCase(StringUtil.stringToBytes("abcdefghijklmnopqrstuvwxyz")), StringUtil.stringToBytes("ABCDEFGHIJKLMNOPQRSTUVWXYZ"));
+        Assert.assertEquals(SequenceUtil.upperCase(StringUtil.stringToBytes("1234567890!@#$%^&*()")), StringUtil.stringToBytes("1234567890!@#$%^&*()"));
+    }
+
+    @Test
+    public void testReverseQualities() {
+
+        final byte[] qualities1 = new byte[] {10, 20, 30, 40};
+        SequenceUtil.reverseQualities(qualities1);
+        assertEquals(qualities1, new byte[] {40, 30, 20, 10});
+
+        final byte[] qualities2 = {10, 20, 30};
+        SequenceUtil.reverseQualities(qualities2);
+        assertEquals(qualities2, new byte[]{30, 20, 10});
+    }
+
+    private void assertEquals(final byte[] actual, final byte[] expected) {
+        Assert.assertEquals(actual.length, expected.length, "Arrays do not have equal lengths");
+
+        for (int i = 0; i < actual.length; ++i) {
+            Assert.assertEquals(actual[i], expected[i], "Array differ at position " + i);
+        }
+    }
+
+    @Test
+    public void testIsACGTN() {
+        for (byte base = Byte.MIN_VALUE; base < Byte.MAX_VALUE; base++) {
+            if (base == 'A' || base == 'C' || base == 'G' || base == 'T' || base == 'N') {
+                Assert.assertTrue(SequenceUtil.isUpperACGTN(base));
+            } else {
+                Assert.assertFalse(SequenceUtil.isUpperACGTN(base));
+            }
+        }
+    }
+
+    @Test
+    public void testIsIUPAC() {
+        final String iupacString = ".aAbBcCdDgGhHkKmMnNrRsStTvVwWyY";
+        for (byte code=0; code<Byte.MAX_VALUE; code++) {
+            if (iupacString.contains(new String (new char[]{(char) code}))) {
+                Assert.assertTrue(SequenceUtil.isIUPAC(code));
+            } else {
+                Assert.assertFalse(SequenceUtil.isIUPAC(code));
+            }
+        }
+    }
+
+    @Test
+    public void testIUPAC_CODES_STRING() {
+        for (final byte code: SequenceUtil.getIUPACCodesString().getBytes()) {
+            Assert.assertTrue(SequenceUtil.isIUPAC(code));
+        }
+    }
+
+    @Test
+    public void testIsBamReadBase() {
+        final String iupacUpperCasedWithoutDot = "=" + SequenceUtil.getIUPACCodesString().toUpperCase().replaceAll("\\.", "N");
+
+        for (byte code = 0; code < Byte.MAX_VALUE; code++) {
+            if (iupacUpperCasedWithoutDot.contains(new String(new char[]{(char) code}))) {
+                Assert.assertTrue(SequenceUtil.isBamReadBase(code));
+            } else {
+                Assert.assertFalse(SequenceUtil.isBamReadBase(code), "" + code);
+            }
+        }
+        Assert.assertTrue(SequenceUtil.isBamReadBase((byte) '='));
+    }
+
+    @Test
+    public void testToBamReadBases() {
+        final String testInput = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz_.-=";
+
+        /**
+         * This can be obtained by :
+         * echo 'blah' | tr a-z A-Z | tr -c '=ABCDGHKMNRSTVWY' N
+         */
+        final String expected = "ABCDNNGHNNKNMNNNNRSTNVWNYNABCDNNGHNNKNMNNNNRSTNVWNYNNNN=";
+
+        Assert.assertEquals(SequenceUtil.toBamReadBasesInPlace(testInput.getBytes()), expected.getBytes());
+    }
 }
