@@ -23,7 +23,17 @@
  */
 package htsjdk.tribble.index.tabix;
 
+import htsjdk.HtsjdkTest;
+import com.google.common.io.Files;
 import htsjdk.samtools.util.BlockCompressedOutputStream;
+import htsjdk.samtools.util.IOUtil;
+import htsjdk.samtools.util.Interval;
+import htsjdk.tribble.AbstractFeatureReader;
+import htsjdk.tribble.FeatureReader;
+import htsjdk.tribble.TestUtils;
+import htsjdk.tribble.Tribble;
+import htsjdk.tribble.bed.BEDCodec;
+import htsjdk.tribble.bed.BEDFeature;
 import htsjdk.tribble.index.IndexFactory;
 import htsjdk.tribble.util.LittleEndianOutputStream;
 import htsjdk.tribble.util.TabixUtils;
@@ -38,11 +48,13 @@ import org.testng.annotations.Test;
 
 import java.io.File;
 import java.io.IOException;
+import java.util.Arrays;
 import java.util.Iterator;
+import java.util.List;
 
-public class TabixIndexTest {
-    private static final File SMALL_TABIX_FILE = new File("src/test/resources/htsjdk/tribble/tabix/trioDup.vcf.gz.tbi");
-    private static final File BIGGER_TABIX_FILE = new File("src/test/resources/htsjdk/tribble/tabix/bigger.vcf.gz.tbi");
+public class TabixIndexTest extends HtsjdkTest {
+    private static final File SMALL_TABIX_FILE = new File(TestUtils.DATA_DIR, "tabix/trioDup.vcf.gz.tbi");
+    private static final File BIGGER_TABIX_FILE = new File(TestUtils.DATA_DIR, "tabix/bigger.vcf.gz.tbi");
 
     /**
      * Read an existing index from disk, write it to a temp file, read that in, and assert that both in-memory
@@ -71,6 +83,8 @@ public class TabixIndexTest {
         };
     }
 
+    //TODO: This test reads an existing .tbi on a .gz, but only writes a .tbi index for a plain vcf, which
+    // tabix doesn't appear to even allow.
     @Test
     public void testQueryProvidedItemsAmount() throws IOException {
         final String VCF = "src/test/resources/htsjdk/tribble/tabix/YRI.trio.2010_07.indel.sites.vcf";
@@ -101,6 +115,8 @@ public class TabixIndexTest {
         ) // create TabixIndex straight from plaintext VCF
                 .write(plainTextVcfIndexFile); // write it
 
+        //TODO: you can pass in a .tbi file as the index for a plain .vcf, but if you *don't* pass in the file name and
+        //just require an index, VCFFleREader will only look for a .idx on a plain vcf
         final VCFFileReader plainTextVcfReader = new VCFFileReader(plainTextVcfInputFile, plainTextVcfIndexFile);
         // Now we have both plaintext and compressed VCFs with provided TabixIndex-es and could test their "queryability"
 
@@ -133,7 +149,79 @@ public class TabixIndexTest {
         }
     }
 
-    private static int countIteratedElements(Iterator iterator) {
+    @DataProvider(name = "bedTabixIndexTestData")
+    public Object[][] getBedIndexFactory(){
+        // These files have accompanying .tbi files created with tabix.
+        return new Object[][] {
+                new Object[] {
+                        // BGZP BED file with no header, 2 features
+                        new File(TestUtils.DATA_DIR, "bed/2featuresNoHeader.bed.gz"),
+                        Arrays.asList(
+                                new Interval("chr1", 1, 10),
+                                new Interval("chr1", 100, 1000000))
+                },
+                new Object[] {
+                        // BGZP BED file with no header, 3 features; one feature falls in between the query intervals
+                        new File(TestUtils.DATA_DIR, "bed/3featuresNoHeader.bed.gz"),
+                        Arrays.asList(
+                                new Interval("chr1", 1, 10),
+                                new Interval("chr1", 100, 1000000))
+                },
+                new Object[] {
+                        // same file as above (BGZP BED file with no header, 3 features), but change the query to return
+                        // only the single interval for the feature that falls in between the other features
+                        new File(TestUtils.DATA_DIR, "bed/3featuresNoHeader.bed.gz"),
+                        Arrays.asList(
+                                new Interval("chr1", 15, 20))
+                },
+                new Object[] {
+                        // BGZP BED file with one line header, 2 features
+                        new File(TestUtils.DATA_DIR, "bed/2featuresWithHeader.bed.gz"),
+                        Arrays.asList(
+                                new Interval("chr1", 1, 10),
+                                new Interval("chr1", 100, 1000000))
+                },
+        };
+    }
+
+    @Test(dataProvider = "bedTabixIndexTestData")
+    public void testBedTabixIndex(
+            final File inputBed,
+            final List<Interval> queryIntervals
+    ) throws Exception {
+        // copy the input file and create an index for the copy
+        final File tempDir = IOUtil.createTempDir("testBedTabixIndex", null);
+        tempDir.deleteOnExit();
+        final File tmpBed = new File(tempDir, inputBed.getName());
+        Files.copy(inputBed, tmpBed);
+        tmpBed.deleteOnExit();
+        final TabixIndex tabixIndexGz = IndexFactory.createTabixIndex(tmpBed, new BEDCodec(), null);
+        tabixIndexGz.writeBasedOnFeatureFile(tmpBed);
+        final File tmpIndex = Tribble.tabixIndexFile(tmpBed);
+        tmpIndex.deleteOnExit();
+
+        // iterate over the query intervals and validate the query results
+        try(final FeatureReader<BEDFeature> originalReader =
+                    AbstractFeatureReader.getFeatureReader(inputBed.getAbsolutePath(), new BEDCodec());
+            final FeatureReader<BEDFeature> createdReader =
+                    AbstractFeatureReader.getFeatureReader(tmpBed.getAbsolutePath(), new BEDCodec()))
+        {
+            for (final Interval interval: queryIntervals) {
+                final Iterator<BEDFeature> originalIt = originalReader.query(interval.getContig(), interval.getStart(), interval.getEnd());
+                final Iterator<BEDFeature> createdIt = createdReader.query(interval.getContig(), interval.getStart(), interval.getEnd());
+                while(originalIt.hasNext()) {
+                    Assert.assertTrue(createdIt.hasNext(), "some features not returned from query");
+                    BEDFeature bedOrig = originalIt.next();
+                    BEDFeature bedTmp = createdIt.next();
+                    Assert.assertEquals(bedOrig.getContig(), bedTmp.getContig());
+                    Assert.assertEquals(bedOrig.getStart(), bedTmp.getStart());
+                    Assert.assertEquals(bedOrig.getEnd(), bedTmp.getEnd());
+                }
+            }
+        }
+    }
+
+    private static int countIteratedElements(final Iterator iterator) {
         int counter = 0;
         while (iterator.hasNext()) {
             iterator.next();
